# coding=utf-8
from __future__ import unicode_literals
from decimal import Decimal

from .. import Provider as AddressProvider


def contains_point(poly, point):
    """
    Given a list of 2-tuples (lat, lng) defining a convex polygon, returns
    True if the given point, which is a 2-tuple (lat, lng), is inside the
    polygon, False otherwise.
    """
    n = len(poly)
    c = False
    i = 0
    j = n - 1
    while i < n:
        if ((poly[i][0] > point[0]) != (poly[j][0] > point[0])) and \
                (point[1] < (poly[j][1] - poly[i][1]) * (point[0] - poly[i][0]) /
                            (poly[j][0] - poly[i][0]) + poly[i][1]):
            c = not c
        j = i
        i += 1
    return c


class Provider(AddressProvider):
    poly = (
        (40.34026, 19.15120),
        (42.21670, 26.13934),
        (35.55680, 29.38280),
        (34.15370, 22.58810),
    )

    building_number_formats = (
        '###',
        '##',
        '##',
        '##',
        '#',
        '#',
        '##-##',
        '###-###',
    )

    street_prefixes_short = (
        'Πλ.',
        'Πάρ.',
        'Λεωφ.',
    )

    street_prefixes_long = (
        'Πλατεία',
        'Πάροδος',
        'Λεωφόρος',
    )

    street_name_formats = (
        '{{street_prefix}} {{street}}',
        '{{street}}',
        '{{street}}',
        '{{street}}',
        '{{last_name_female}}',
    )

    street_address_formats = (
        '{{street_name}} {{building_number}}',
    )

    postcode_formats = (
        '### ##',
        '#####',
        '#####',
        'ΤΚ ### ##',
        'ΤΚ #####',
    )

    address_formats = (
        "{{street_address}},\n{{postcode}} {{city}}",
    )

    line_address_formats = (
        "{{street_address}}, {{postcode}} {{city}}",
    )

    def line_address(self):
        pattern = self.random_element(self.line_address_formats)
        return self.generator.parse(pattern)

    def street_prefix(self):
        return self.random_element(
            self.street_prefixes_short +
            self.street_prefixes_long)

    def street_prefix_short(self):
        return self.random_element(self.street_prefixes_short)

    def street_prefix_long(self):
        return self.random_element(self.street_prefixes_long)

    def street(self):
        return self.random_element(self.localities)

    def city(self):
        return self.random_element(self.cities)

    def region(self):
        return self.random_element(self.regions)

    def latlng(self):
        return float(self.latitude()), float(self.longitude())

    def latitude(self):
        l = list(map(lambda t: int(t[0] * 10000000), self.poly))
        return Decimal(str(self.generator.random.randint(
            min(l), max(l)) / 10000000.0)).quantize(Decimal('.000001'))

    def longitude(self):
        l = list(map(lambda t: int(t[1] * 10000000), self.poly))
        return Decimal(str(self.generator.random.randint(
            min(l), max(l)) / 10000000.0)).quantize(Decimal('.000001'))

    # Ονόματα πρωτευουσών νομών
    cities = (
        'Άμφισσα',
        'Άρτα',
        'Έδεσσα',
        'Αγ. Νικόλαος',
        'Αθήνα',
        'Αλεξανδρούπολη',
        'Αργοστόλι',
        'Βέροια',
        'Βόλος',
        'Γρεβενά',
        'Δράμα',
        'Ερμούπολη',
        'Ζάκυνθος',
        'Ηγουμενίτσα',
        'Ηράκλειο',
        'Θεσσαλονίκη',
        'Ιωάννινα',
        'Κέρκυρα',
        'Καβάλα',
        'Καλαμάτα',
        'Καρδίτσα',
        'Καρπενήσι',
        'Καστοριά',
        'Κατερίνη',
        'Κιλκίς',
        'Κοζάνη',
        'Κομοτηνή',
        'Κόρινθος',
        'Λάρισα',
        'Λαμία',
        'Λευκάδα',
        'Λιβαδιά',
        'Μεσολόγγι',
        'Μυτιλήνη',
        'Ναύπλιο',
        'Ξάνθη',
        'Πάτρα',
        'Πολύγυρος',
        'Πρέβεζα',
        'Πύργος',
        'Ρέθυμνο',
        'Ρόδος',
        'Σάμος',
        'Σέρρες',
        'Σπάρτη',
        'Τρίκαλα',
        'Τρίπολη',
        'Φλώρινα',
        'Χίος',
        'Χαλκίδα',
        'Χανιά',
    )

    # Ονόματα νομών
    regions = (
        'Αιτωλία & Ακαρνανία', 'Αργολίδα', 'Αρκαδία', 'Άρτα', 'Αττική', 'Αχαΐα',
        'Βοιωτία', 'Γρεβενά', 'Δράμα', 'Δωδεκάνησσος', 'Έβρος', 'Ευρυτανία',
        'Εύβοια', 'Ζάκυνθος', 'Ηλεία', 'Ημαθία', 'Ηράκλειο', 'Θεσπρωτία',
        'Θεσσαλονίκη', 'Ιωάννινα', 'Κέρκυρα', 'Καβάλα', 'Καρδίτσα', 'Καστοριά',
        'Κεφαλληνία', 'Κιλκίς', 'Κοζάνη', 'Κορινθία', 'Κυκλάδες', 'Λάρισσα',
        'Λέσβος', 'Λακωνία', 'Λασσίθι', 'Λευκάδα', 'Μαγνησία', 'Μεσσηνία',
        'Ξάνθη', 'Πέλλα', 'Πιερία', 'Πρέβεζα', 'Ρέθυμνο', 'Ροδόπη', 'Σάμος',
        'Σέρρες', 'Τρίκαλα', 'Φθιώτιδα', 'Φλώρινα', 'Φωκίδα', 'Χίος',
        'Χαλκιδική', 'Χανιά',
    )

    # Ονόματα χωρών
    countries = (
        'Άγιος Βαρθολομαίος', 'Άγιος Βικέντιος και Γρεναδίνες', 'Άγιος Μαρίνος',
        'Άγιος Μαρτίνος', 'Άγιος Μαρτίνος (Γαλλικό Κομμάτι)', 'Άγιος Πέτρος και Μικελόν',
        'Άγιος Χριστόφορος και Νέβις', 'Αίγυπτος', 'Αγία Ελένη, Ασενσιόν και Τριστάν ντα Κούνια',
        'Αγία Λουκία', 'Αζερμπαϊτζάν', 'Αιθιοπία', 'Ακτή Ελεφαντοστού', 'Αλβανία',
        'Αλγερία', 'Αμερικανικές Παρθένοι Νήσοι', 'Αμερικανική Σαμόα', 'Ανατολικό Τιμόρ',
        'Ανγκουίλα', 'Ανγκόλα', 'Ανδόρα', 'Αντίγκουα και Μπαρμπούντα', 'Ανταρκτική',
        'Απομακρυσμένες Νησίδες των Ηνωμένων Πολιτειών', 'Αραβική Δημοκρατία της Λιβύης',
        'Αργεντινή', 'Αρμενία', 'Αρούμπα', 'Αυστρία', 'Αυστραλία', 'Αφγανιστάν', 'Αϊτή',
        'Βέλγιο', 'Βανουάτου', 'Βατικανό', 'Βενεζουέλα', 'Βερμούδες', 'Βιετνάμ', 'Βολιβία',
        'Βοσνία-Ερζεγοβίνη', 'Βουλγαρία', 'Βραζιλία', 'Βρετανικές Παρθένοι Νήσοι',
        'Βρετανικό Έδαφος Ινδικού Ωκεανού', 'Βόρειες Μαριάνες Νήσοι', 'Γαλλία',
        'Γαλλικά Νότια και Ανταρκτικά Εδάφη', 'Γαλλική Γουιάνα', 'Γαλλική Πολυνησία',
        'Γερμανία', 'Γεωργία', 'Γιβραλτάρ', 'Γκάμπια', 'Γκάνα', 'Γκέρνσεϊ', 'Γκαμπόν',
        'Γκουάμ', 'Γουάλις και Φουτούνα', 'Γουαδελούπη', 'Γουατεμάλα', 'Γουιάνα',
        'Γουινέα', 'Γουινέα-Μπισσάου', 'Γρενάδα', 'Γροιλανδία', 'Δανία', 'Δημοκρατία της Κορέας',
        'Δομινίκα', 'Δομινικανή Δημοκρατία', 'Δυτική Σαχάρα', 'Ελ Σαλβαδόρ', 'Ελβετία',
        'Ελλάδα', 'Ερυθραία', 'Εσθονία', 'Ζάμπια', 'Ζιμπάμπουε', 'Ηνωμένα Αραβικά Εμιράτα',
        'Ηνωμένες Πολιτείες Αμερικής', 'Ηνωμένο Βασίλειο', 'Ιαπωνία', 'Ινδία', 'Ινδονησία',
        'Ιορδανία', 'Ιράκ', 'Ιράν', 'Ιρλανδία', 'Ισημερινή Γουινέα', 'Ισημερινός', 'Ισλανδία',
        'Ισπανία', 'Ισραήλ', 'Ιταλία', 'Κένυα', 'Κίνα', 'Καζακστάν', 'Καμερούν', 'Καμπότζη',
        'Καναδάς', 'Κατάρ', 'Κεντροαφρικανική Δημοκρατία', 'Κιργιστάν', 'Κιριμπάτι',
        'Κολομβία', 'Κομόρες', 'Κονγκό', 'Κουβέιτ', 'Κουρακάο', 'Κούβα', 'Κροατία',
        'Κόστα Ρίκα', 'Κύπρος', 'Λίβανος', 'Λαοκρατική Δημοκρατία της Κορέας',
        'Λαϊκή Δημοκρατία του Κονγκό', 'Λαϊκή Δημοκρατία του Λάος', 'Λεσότο',
        'Λετονία', 'Λευκορωσία', 'Λιβερία', 'Λιθουανία', 'Λιχτενστάϊν', 'Λουξεμβούργο',
        'Μάλι', 'Μάλτα', 'Μαγιότ', 'Μαδαγασκάρη', 'Μακάο', 'Μαλάουι', 'Μαλαισία',
        'Μαλδίβες', 'Μαρτινίκη', 'Μαρόκο', 'Μαυρίκιος', 'Μαυριτανία', 'Μαυροβούνιο',
        'Μεξικό', 'Μιανμάρ', 'Μικρονησία', 'Μογγολία', 'Μοζαμβίκη', 'Μολδαβία',
        'Μονακό', 'Μονσεράτ', 'Μπαγκλαντές', 'Μπαρμπάντος', 'Μπαχάμες', 'Μπαχρέιν',
        'Μπελίζ', 'Μπενίν', 'Μποτσουάνα', 'Μπουρκίνα Φάσο', 'Μπουρουντί', 'Μπουτάν',
        'Μπρουνέι', 'Νέα Ζηλανδία', 'Νέα Καληδονία', 'Νήσοι Κουκ', 'Νήσοι Κόκος',
        'Νήσοι Μάρσαλ', 'Νήσοι Πίτκαιρν', 'Νήσοι Σολομώντα', 'Νήσοι Φώκλαντ',
        'Νήσοι Χερντ και Μακντόναλντ', 'Νήσοι Ώλαντ', 'Νήσος Μαν', 'Νήσος Μπουβέ',
        'Νήσος των Χριστουγέννων', 'Νίγηρας', 'Ναμίμπια', 'Ναουρού', 'Νεπάλ',
        'Νησί Νόρφολκ', 'Νησιά Καϋμάν', 'Νησιά Τερκς και Κάικος', 'Νησιά Φερόες',
        'Νιγηρία', 'Νικαράγουα', 'Νιούε', 'Νορβηγία', 'Νότιος Αφρική',
        'Νότιος Γεωργία και οι Νότιοι Σάντουιτς Νήσοι', 'Ολλανδία', 'Ολλανδικές Αντίλλες',
        'Ομάν', 'Ονδούρα', 'Ουγγαρία', 'Ουγκάντα', 'Ουζμπεκιστάν', 'Ουκρανία', 'Ουρουγουάη',
        'Π.Γ.Δ. Μακεδονίας', 'Πακιστάν', 'Παλάου', 'Παλαιστίνη', 'Παναμάς',
        'Παπούα Νέα Γουινέα', 'Παραγουάη', 'Περού', 'Πολωνία', 'Πορτογαλία',
        'Πουέρτο Ρίκο', 'Πράσινο Ακρωτήρι', 'Ρεϊνιόν', 'Ρουάντα', 'Ρουμανία',
        'Ρωσία', 'Σάο Τομέ και Πρίνσιπε', 'Σαμόα', 'Σαουδική Αραβία',
        'Σβάλμπαρντ και Γιαν Μαγιέν', 'Σενεγάλη', 'Σερβία', 'Σεϋχέλλες',
        'Σιέρα Λεόνε', 'Σιγκαπούρη', 'Σλοβακία', 'Σλοβενία', 'Σομαλία',
        'Σουαζιλάνδη', 'Σουδάν', 'Σουηδία', 'Σουρινάμ', 'Σρι Λάνκα', 'Συρία',
        'Τανζανία', 'Τατζικιστάν', 'Ταϊβάν', 'Ταϊλάνδη', 'Τζέρσεϊ', 'Τζαμάικα',
        'Τζιμπουτί', 'Τοκελάου', 'Τουβαλού', 'Τουρκία', 'Τουρκμενιστάν',
        'Τρινιντάντ και Τομπάγκο', 'Τσαντ', 'Τσεχία', 'Τυνησία', 'Τόγκο',
        'Τόνγκα', 'Υεμένη', 'Φίτζι', 'Φιλιππίνες', 'Φινλανδία', 'Χιλή', 'Χονγκ Κονγκ',
    )

    # Επίσημα τοπικά διαμερίσματα.
    # Χρησιμοποιούνται ως ονόματα δρόμων (λόγω ανάγκης για γενική κλίση).
    # Η λίστα είναι από το ΥΠ.ΕΣ. (μετά από επεξεργασία και μορφοποίηση)
    localities = (
        'Άγρα',
        'Άγρας',
        'Άδελε',
        'Άκρης',
        'Άλλης Μεριάς',
        'Άλσους',
        'Άμμου',
        'Άμπλιανης',
        'Άνδρου',
        'Άργους',
        'Άργους Ορεστικού',
        'Άρζου',
        'Άρλας',
        'Άρμπουνα',
        'Άρνης',
        'Άσκρης',
        'Άσου',
        'Άσπρου',
        'Άσπρων Σπιτιών',
        'Άσσου',
        'Άστρους',
        'Άτταλης',
        'Άφρας',
        'Έλους',
        'Έμπωνα',
        'Έρφων',
        'Ήπιον',
        'Ήρας',
        'Ίδας',
        'Ίμπρου',
        'Ίσαρη',
        'Αΐμονα',
        'Αβάτου',
        'Αβίας',
        'Αβαρίκου',
        'Αβγαριάς',
        'Αβγού',
        'Αβδέλλας',
        'Αβδήρων',
        'Αβδού',
        'Αβρακόντε',
        'Αβραμιού',
        'Αβραμυλιάς',
        'Αβόρανης',
        'Αβόρου',
        'Αγάπης',
        'Αγία Βαρβάρα',
        'Αγία Κυριακή',
        'Αγία Παρασκευή',
        'Αγίας Άννας',
        'Αγίας Άννης',
        'Αγίας Αναστασίας',
        'Αγίας Βαρβάρας',
        'Αγίας Βλαχέρνης',
        'Αγίας Γαλήνης',
        'Αγίας Ειρήνης',
        'Αγίας Ελένης',
        'Αγίας Ευθυμίας',
        'Αγίας Ευφημίας',
        'Αγίας Θέκλης',
        'Αγίας Κυριακής',
        'Αγίας Μαρίνης',
        'Αγίας Μαύρας',
        'Αγίας Παρασκευής',
        'Αγίας Ρουμέλης',
        'Αγίας Σοφίας',
        'Αγίας Σωτήρας',
        'Αγίου',
        'Αγίου Αδριανού',
        'Αγίου Αθανασίου',
        'Αγίου Ακακίου',
        'Αγίου Ανδρέου',
        'Αγίου Αντωνίου',
        'Αγίου Αρσενίου',
        'Αγίου Αχιλλείου',
        'Αγίου Βαρθολομαίου',
        'Αγίου Βασιλείου',
        'Αγίου Βασιλείου Κυνουρίας',
        'Αγίου Βασιλείου Μαντινείας',
        'Αγίου Βησσαρίου',
        'Αγίου Βλασίου',
        'Αγίου Γερμανού',
        'Αγίου Γεωργίου',
        'Αγίου Γεωργίου Δομοκού',
        'Αγίου Γεωργίου Λαρίσης',
        'Αγίου Γεωργίου Λασιθίου',
        'Αγίου Γεωργίου Νηλείας',
        'Αγίου Γεωργίου Σητείας',
        'Αγίου Γεωργίου Συκούση',
        'Αγίου Γεωργίου Φαρσάλων',
        'Αγίου Γεωργίου Φερών',
        'Αγίου Δημητρίου',
        'Αγίου Δημητρίου Μονεμβασίας',
        'Αγίου Δημητρίου Πηλίου',
        'Αγίου Ευστρατίου',
        'Αγίου Ηλία',
        'Αγίου Ηλία Πηνηίων',
        'Αγίου Ηλία Πύργου',
        'Αγίου Θεοδώρου',
        'Αγίου Θωμά',
        'Αγίου Ισιδώρου',
        'Αγίου Ιωάννη',
        'Αγίου Ιωάννου',
        'Αγίου Ιωάννου Αγίου Βασιλείου',
        'Αγίου Ιωάννου Αμαρίου',
        'Αγίου Ιωάννου Αρχαίας Ηραίας',
        'Αγίου Ιωάννου Επιδαύρου Λιμήρας',
        'Αγίου Ιωάννου Μυλοποτάμου',
        'Αγίου Ιωάννου Ρέντη',
        'Αγίου Κηρύκου',
        'Αγίου Κοσμά',
        'Αγίου Κυρίλλου',
        'Αγίου Κωνσταντίνου',
        'Αγίου Λαυρεντίου',
        'Αγίου Λουκά',
        'Αγίου Μάρκου',
        'Αγίου Ματθαίου',
        'Αγίου Μηνά',
        'Αγίου Νικήτα',
        'Αγίου Νικολάου',
        'Αγίου Νικολάου Βοιών',
        'Αγίου Νικολάου Βονίτσης και Ξηρομέρου',
        'Αγίου Νικολάου Κράλης',
        'Αγίου Νικολάου Μονεμβασίας',
        'Αγίου Νικολάου Σπάτων',
        'Αγίου Ονουφρίου',
        'Αγίου Πέτρου',
        'Αγίου Παντελεήμονα',
        'Αγίου Παύλου',
        'Αγίου Πολυκάρπου',
        'Αγίου Προδρόμου',
        'Αγίου Προκοπίου',
        'Αγίου Σεραφείμ',
        'Αγίου Στεφάνου',
        'Αγίου Σύλλα',
        'Αγίου Σώστου',
        'Αγίου Φλώρου',
        'Αγίου Χαραλάμπους',
        'Αγίου Χριστοφόρου',
        'Αγίων Αναργύρων',
        'Αγίων Αποστόλων',
        'Αγίων Δέκα',
        'Αγίων Δούλων',
        'Αγίων Θεοδώρων',
        'Αγίων Πάντων',
        'Αγίων Παρασκιών',
        'Αγαθονησίου',
        'Αγαθουπόλεως',
        'Αγαλά',
        'Αγαλιανής',
        'Αγαλιανού',
        'Αγγίστης',
        'Αγγελιανών',
        'Αγγελοκάστρου',
        'Αγγελοχωρίου',
        'Αγγελώνας',
        'Αγδινών',
        'Αγιάς',
        'Αγιάσου',
        'Αγιοβλασιτίκων',
        'Αγιονερίου',
        'Αγιονορίου',
        'Αγιοπηγής',
        'Αγιοφύλλου',
        'Αγιοχωρίου',
        'Αγιοχώριον',
        'Αγιωργιτίκων',
        'Αγκίστρου',
        'Αγκαθιάς',
        'Αγκαιριάς',
        'Αγκαρυώνων',
        'Αγκιστρίου',
        'Αγκουσελιανών',
        'Αγνάντης',
        'Αγνάντων',
        'Αγναντερής',
        'Αγναντερού',
        'Αγναντιάς',
        'Αγοράς',
        'Αγράφων',
        'Αγρίλου',
        'Αγραμπέλων',
        'Αγραπιδεών',
        'Αγραπιδιάς',
        'Αγραπιδοχωρίου',
        'Αγραφών',
        'Αγρελιάς',
        'Αγριάνων',
        'Αγριάς',
        'Αγριακόνας',
        'Αγριανής',
        'Αγριδίου',
        'Αγριλιάς Μεσσήνης',
        'Αγριλιάς Τριφυλίας',
        'Αγριλοβούνου',
        'Αγρινίου',
        'Αγριοβοτάνου',
        'Αγροσυκέας',
        'Αγρού',
        'Αγχιάλου',
        'Αγόριανης',
        'Αδάμ',
        'Αδένδρου',
        'Αδαμίου',
        'Αδελφικού',
        'Αδριανής',
        'Αερινού',
        'Αετολόφου',
        'Αετομηλίτσης',
        'Αετοπέτρας',
        'Αετοπέτρας Δωδώνης',
        'Αετοπέτρας Κονίτσης',
        'Αετορράχη',
        'Αετορράχης',
        'Αετού',
        'Αζώρου',
        'Αηδονίων',
        'Αηδονιάς',
        'Αηδονοχωρίου',
        'Αθαμανίας',
        'Αθαμανίου',
        'Αθανίου',
        'Αθανασίου Διάκου',
        'Αθηναίου',
        'Αθηναίων',
        'Αθικίων',
        'Αθύρων',
        'Αιανής',
        'Αιαντείου',
        'Αιγάλεω',
        'Αιγάνης',
        'Αιγίνης',
        'Αιγίου',
        'Αιγείρας',
        'Αιγείρου',
        'Αιγιάλης',
        'Αιγινίου',
        'Αιγιών',
        'Αιγών',
        'Αιθαίας',
        'Αισύμης',
        'Αιτωλικού',
        'Ακοντίου',
        'Ακουμίων',
        'Ακράτας',
        'Ακρίτα',
        'Ακρίτας',
        'Ακρίων',
        'Ακραιφνίου',
        'Ακρασίου',
        'Ακρινής',
        'Ακριτοχωρίου',
        'Ακρολίμνης',
        'Ακροποτάμου',
        'Ακροποταμιάς',
        'Ακρωτηρίου',
        'Ακρών',
        'Ακταίου',
        'Ακόβου',
        'Αλέας',
        'Αλίκων',
        'Αλίμου',
        'Αλαγνίου',
        'Αλαγονίας',
        'Αλαλκομενών',
        'Αλατόπετρας',
        'Αλειμματάδων',
        'Αλεξάνδρου',
        'Αλεξανδρείας',
        'Αλεξανδρουπόλεως',
        'Αλεποχωρίου',
        'Αλεποχωρίου Μπότσαρη',
        'Αλεπούς',
        'Αλεστίων',
        'Αλεσταίνης',
        'Αλευράδας',
        'Αλευρούς',
        'Αληθινής',
        'Αλιάρτου',
        'Αλιβερίου',
        'Αλικάμπου',
        'Αλικανά',
        'Αλικαρνασσού',
        'Αλικιανού',
        'Αλισσού',
        'Αλιστράτης',
        'Αλιφείρας',
        'Αλμυροποτάμου',
        'Αλμυρού',
        'Αλοίδων',
        'Αλοννήσου',
        'Αλποχωρίου',
        'Αλτομιρών',
        'Αλυφαντών',
        'Αλφάς',
        'Αλφειούσης',
        'Αλωνίων',
        'Αλωνακίων',
        'Αλωνισταίνης',
        'Αλώνων',
        'Αλώρου',
        'Αμάδων',
        'Αμαλιαπόλεως',
        'Αμαξάδων',
        'Αμαράντου',
        'Αμαράντων',
        'Αμαρίου',
        'Αμαριανού',
        'Αμαρουσίου',
        'Αμαρύνθου',
        'Αμβρακίας',
        'Αμβροσίας',
        'Αμελάντων',
        'Αμιρά',
        'Αμισιανών',
        'Αμμολόχου',
        'Αμμοτόπου',
        'Αμμουδάρας',
        'Αμμουδιάς',
        'Αμμουλιανής',
        'Αμμοχωρίου',
        'Αμνάτου',
        'Αμορίου',
        'Αμοργιανών',
        'Αμοργού',
        'Αμουρίου',
        'Αμπέλου',
        'Αμπέλων',
        'Αμπελίων',
        'Αμπελακίου',
        'Αμπελακίων',
        'Αμπελακιωτίσσης',
        'Αμπελείας',
        'Αμπελειών',
        'Αμπελιάς',
        'Αμπελικού',
        'Αμπελιώνας',
        'Αμπελοκάμπου',
        'Αμπελοκήπων',
        'Αμπελοφύτου',
        'Αμπελοχωρίου',
        'Αμπελούζου',
        'Αμυγδαλέας',
        'Αμυγδαλής',
        'Αμυγδαλεών',
        'Αμυγδαλιάς',
        'Αμυγδαλοκεφαλίου',
        'Αμυκλών',
        'Αμυνταίου',
        'Αμφία',
        'Αμφίσσης',
        'Αμφείας',
        'Αμφιθέας',
        'Αμφικλείας',
        'Αμφιλοχίας',
        'Αμφιπόλεως',
        'Ανάβατου',
        'Ανάβρας',
        'Ανάφης',
        'Ανέζης',
        'Αναβρυτής',
        'Αναβρυτού',
        'Αναβρυτών',
        'Αναβύσσου',
        'Αναγεννήσεως',
        'Ανακασιάς',
        'Αναλήψεως',
        'Αναργύρων',
        'Αναρράχης',
        'Αναστάσεως',
        'Αναστασίας',
        'Ανατολής',
        'Ανατολικής',
        'Ανατολικής Φραγκίστας',
        'Ανατολικού',
        'Αναφωνητρίας',
        'Ανδανίας',
        'Ανδρίτσης',
        'Ανδραβίδας',
        'Ανδριτσαίνης',
        'Ανδρούσης',
        'Ανδρωνιάνων',
        'Ανεμοδουρίου',
        'Ανεμομύλου',
        'Ανεμορράχης',
        'Ανεμοχωρίου',
        'Ανεμότιας',
        'Ανηλίου',
        'Ανθήλης',
        'Ανθής',
        'Ανθείας',
        'Ανθηρού',
        'Ανθοτόπου',
        'Ανθοφύτου',
        'Ανθοχωρίου',
        'Ανθοχωρίου Δωδώνης',
        'Ανθοχωρίου Μετσόβου',
        'Ανθοχώριον',
        'Ανθούσης',
        'Ανθρακίτη',
        'Ανιάδας',
        'Ανοίξεως',
        'Ανοιξιάτικου',
        'Αντίσσης',
        'Ανταρτικού',
        'Αντιγονείας',
        'Αντικαλάμου',
        'Αντικυθήρων',
        'Αντικύρας',
        'Αντιμαχείας',
        'Αντιπάρου',
        'Αντιπάτων Ερίσου',
        'Αντιπερνών',
        'Αντιρρίου',
        'Αντισκαρίου',
        'Αντιφιλίππων',
        'Αντρωνίου',
        'Ανυφίου',
        'Ανωγής',
        'Ανωγείου',
        'Ανωγείων',
        'Ανωπόλεως',
        'Ανύδρου',
        'Ανώσκελης',
        'Αξιοκάστρου',
        'Αξιουπόλεως',
        'Αξιοχωρίου',
        'Αξού',
        'Απεράθου',
        'Απερίου',
        'Απεσωκαρίου',
        'Απιδέα',
        'Απιδέας',
        'Απιδίων',
        'Απλαδιανών',
        'Αποδούλου',
        'Αποικίων',
        'Απολακκιάς',
        'Απολλωνίας',
        'Απολπαίνης',
        'Αποστολιά',
        'Αποστόλων',
        'Απροβάτου',
        'Απτέρων',
        'Απόλλωνα',
        'Αράξου',
        'Αράχου',
        'Αρήνης',
        'Αρίας',
        'Αρίσβη',
        'Αρίσβης',
        'Αρίστης',
        'Αραβησσού',
        'Αραχαμιτών',
        'Αραχναίου',
        'Αραχοβιτίκων',
        'Αραχόβης',
        'Αρβανίτη',
        'Αργέννου',
        'Αργίλου',
        'Αργαλαστής',
        'Αργασίου',
        'Αργιθέας',
        'Αργινίων',
        'Αργολικού',
        'Αργοστολίου',
        'Αργυράδων',
        'Αργυράς',
        'Αργυρίου',
        'Αργυρίων',
        'Αργυροπουλείου',
        'Αργυροτόπου',
        'Αργυρουπόλεως',
        'Αργυροχωρίου',
        'Αργυρού',
        'Αργυρού Πηγαδίου',
        'Αργυρούπολης',
        'Αργυρούπολις',
        'Αρδάκτου',
        'Αρδάσσης',
        'Αρδαμερίου',
        'Αρδανίου',
        'Αρδείας',
        'Αρδόσεως',
        'Αρεθούσης',
        'Αρεοπόλεως',
        'Αρετής',
        'Αριδαίας',
        'Αριοχωρίου',
        'Αριστοδημείου',
        'Αριστομένους',
        'Αρκάσας',
        'Αρκίτσας',
        'Αρκαδάδων',
        'Αρκαδικού',
        'Αρκαλοχωρίου',
        'Αρκεσίνης',
        'Αρκοχωρίου',
        'Αρμάτων',
        'Αρμένων',
        'Αρματολικού',
        'Αρμενάδων',
        'Αρμενίου',
        'Αρμενιών',
        'Αρμενοχωρίου',
        'Αρμολίων',
        'Αρνά',
        'Αρνίθας',
        'Αρνίσσης',
        'Αρναίας',
        'Αροανίας',
        'Αρραβωνίτσης',
        'Αρριανά',
        'Αρσενίου',
        'Αρσινόης',
        'Αρτάκης',
        'Αρτέμιδας',
        'Αρταίων',
        'Αρτεμισίας',
        'Αρτεμισίου',
        'Αρτεσιανού',
        'Αρτικίου',
        'Αρτοπούλας',
        'Αρτοτίνας',
        'Αρφαρών',
        'Αρχαίας Ήλιδας',
        'Αρχαίας Ελεύθερνας',
        'Αρχαίας Επιδαύρου',
        'Αρχαίας Κορίνθου',
        'Αρχαίας Μεσσήνης',
        'Αρχαίας Νεμέας',
        'Αρχαίας Ολυμπίας',
        'Αρχαίας Πίσας',
        'Αρχαίας Φενεού',
        'Αρχαίων Κλεωνών',
        'Αρχαγγέλου',
        'Αρχανίου',
        'Αρχανών',
        'Αρχιλόχου',
        'Αρχιπόλεως',
        'Αρχοντικά',
        'Αρχοντικής',
        'Αρχοντικού',
        'Αρχοντοχωρίου',
        'Αρωγή',
        'Αρωνά',
        'Αρωνίου',
        'Αρωνιαδίκων',
        'Ασέας',
        'Ασή Γωνιάς',
        'Ασίνης',
        'Ασβεστάδων',
        'Ασβεστίου',
        'Ασβεστοπέτρας',
        'Ασβεστοχωρίου',
        'Ασημένιου',
        'Ασημίου',
        'Ασημοχωρίου',
        'Ασιτών',
        'Ασκληπιείου',
        'Ασκού',
        'Ασκύφου',
        'Ασκών',
        'Ασμηνίου',
        'Ασπραγγέλων',
        'Ασπριάς',
        'Ασπροβάλτας',
        'Ασπρογείων',
        'Ασπρογερακάτων',
        'Ασπροκάμπου',
        'Ασπροκκλησίου',
        'Ασπροκκλησιάς',
        'Ασπρονερίου',
        'Ασπροπουλιάς',
        'Ασπροπύργου',
        'Ασπροχωρίου',
        'Ασπρούλας',
        'Ασσήρου',
        'Αστακού',
        'Αστερίου',
        'Αστρά',
        'Αστράκων',
        'Αστρίτσης',
        'Αστριτσίου',
        'Αστροχωρίου',
        'Αστυπαλαίας',
        'Αστυρακίου',
        'Ασφάκας',
        'Ασφένδου',
        'Ασφενδιού',
        'Ασωμάτου',
        'Ασωμάτων',
        'Ασωπίας',
        'Ασωπού',
        'Ασώματα',
        'Αταλάντης',
        'Ατραπού',
        'Ατσικής',
        'Ατσιποπούλου',
        'Ατσιχόλου',
        'Αυγής',
        'Αυγείου',
        'Αυγενικής',
        'Αυγερινού',
        'Αυγώνυμων',
        'Αυλής',
        'Αυλακίου',
        'Αυλιωτών',
        'Αυλοτόπου',
        'Αυλωναρίου',
        'Αυλών',
        'Αφάντου',
        'Αφετών',
        'Αφιδνών',
        'Αφισίου',
        'Αφράτου',
        'Αφράτων',
        'Αφρατίου',
        'Αφροξυλιάς',
        'Αφύτου',
        'Αχαΐας',
        'Αχαρνών',
        'Αχαϊκού',
        'Αχεντριά',
        'Αχερουσίας',
        'Αχιλλείου',
        'Αχινού',
        'Αχλάδας',
        'Αχλαδέ',
        'Αχλαδέας',
        'Αχλαδίου',
        'Αχλαδίων',
        'Αχλαδερής',
        'Αχλαδεών',
        'Αχλαδινής',
        'Αχλαδοκάμπου',
        'Αχλαδοκάστρου',
        'Αχλαδοχωρίου',
        'Αχυρών',
        'Αψάλου',
        'Αϊδινίου',
        'Αϊτανίων',
        'Αύρας',
        'Βάβδου',
        'Βάγγου',
        'Βάθειας',
        'Βάθης',
        'Βάλτας',
        'Βάλτου',
        'Βάμου',
        'Βάρδας',
        'Βάρης',
        'Βάρνακα',
        'Βάρους',
        'Βάστα',
        'Βάτου',
        'Βάχλιας',
        'Βάχου',
        'Βέλου',
        'Βέλους',
        'Βέργας',
        'Βέργης',
        'Βέροιας',
        'Βέσσης',
        'Βήσσανης',
        'Βίβλου',
        'Βίγλας',
        'Βίνιανης',
        'Βίτολης',
        'Βίτσης',
        'Βαβιλών',
        'Βαβουρίου',
        'Βαγίων',
        'Βαγενιτίου',
        'Βαγιονιάς',
        'Βαθέως',
        'Βαθείας',
        'Βαθυκοίλου',
        'Βαθυλάκκου',
        'Βαθυπέδου',
        'Βαθυτόπου',
        'Βαλανίδας',
        'Βαλανείου',
        'Βαλανιδιάς',
        'Βαλανιδοράχης',
        'Βαλανιδούσσας',
        'Βαλαώρας',
        'Βαλεριάνου',
        'Βαλιμής',
        'Βαλιμιτίκων',
        'Βαλκάνου',
        'Βαλσαμονέρου',
        'Βαλτερού',
        'Βαλτεσινίκου',
        'Βαλτετσίου',
        'Βαλτινού',
        'Βαλτονέρων',
        'Βαλτοτοπίου',
        'Βαλτοχωρίου',
        'Βαλύρας',
        'Βαμβακιάς',
        'Βαμβακοπούλου',
        'Βαμβακοφύτου',
        'Βαμβακούς',
        'Βαμβακούσσης',
        'Βανάδας',
        'Βανάτου',
        'Βαπτιστού',
        'Βαρβάρας',
        'Βαρβίτσης',
        'Βαρβασαίνης',
        'Βαργιάδων',
        'Βαργιάνης',
        'Βαρδάτων',
        'Βαρδαλής',
        'Βαρετάδας',
        'Βαρθολομιού',
        'Βαρικού',
        'Βαρλαάμ',
        'Βαρνάβα',
        'Βαρυπατάδων',
        'Βαρύπετρου',
        'Βασαρά',
        'Βασιλή',
        'Βασιλακίου',
        'Βασιλατίκων',
        'Βασιλειών',
        'Βασιλεωνοίκου',
        'Βασιλικής',
        'Βασιλικιάδων',
        'Βασιλικού',
        'Βασιλικών',
        'Βασιλικών Ανωγείων',
        'Βασιλιτσίου',
        'Βασιλοπούλου',
        'Βασιλουδίου',
        'Βατίου',
        'Βατατάδων',
        'Βατερού',
        'Βατολάκκου',
        'Βατοχωρίου',
        'Βατούσσης',
        'Βατσουνιάς',
        'Βαυκερής',
        'Βαφέ',
        'Βαφιοχωρίου',
        'Βαχού',
        'Βεγόρων',
        'Βελάς',
        'Βελίκας',
        'Βελίνης',
        'Βελανιδίου',
        'Βελανιδίων',
        'Βελανιδιάς',
        'Βελβίνας',
        'Βελβεντού',
        'Βελεντζικού',
        'Βελεσιωτών',
        'Βελεστίνου',
        'Βελημαχίου',
        'Βελιγοστής',
        'Βελιμαχίου',
        'Βελιτσών',
        'Βελιών',
        'Βελονάδων',
        'Βελωτών',
        'Βενίου',
        'Βενεράτου',
        'Βερίνου',
        'Βερβένων',
        'Βερβεράτου',
        'Βεργίνης',
        'Βερδικούσσης',
        'Βερενίκης',
        'Βερμίου',
        'Βερτίσκου',
        'Βεύης',
        'Βιάννου',
        'Βιδιακίου',
        'Βιζαρίου',
        'Βικίου',
        'Βιλίων',
        'Βιλανδρέδου',
        'Βιλιβίνης',
        'Βιρού',
        'Βισταγής',
        'Βιτάλων',
        'Βιταλάδων',
        'Βιταλίου',
        'Βλάση',
        'Βλάστης',
        'Βλάτους',
        'Βλασίας',
        'Βλασίου',
        'Βλαχάβας',
        'Βλαχάτων Εικοσιμίας',
        'Βλαχέρνης',
        'Βλαχατάνου',
        'Βλαχερωνιτίσσης',
        'Βλαχιάς',
        'Βλαχιώτη',
        'Βλαχογιαννίου',
        'Βλαχοκερασέας',
        'Βλαχομάνδρας',
        'Βλαχοπούλου',
        'Βλησιδιάς',
        'Βλιζιανών',
        'Βλοχού',
        'Βλυχού',
        'Βοβούσης',
        'Βογατσικού',
        'Βοθιανών',
        'Βολιμών',
        'Βολισσού',
        'Βομβοκούς',
        'Βορδονίας',
        'Βορεινού',
        'Βοριζίων',
        'Βοσκοχωρίου',
        'Βοτονοσίου',
        'Βουβοποτάμου',
        'Βουβών',
        'Βουγιάτου',
        'Βουζίου',
        'Βουκολιών',
        'Βουλγάρω',
        'Βουλιάστης',
        'Βουλιαγμένης',
        'Βουλισμένης',
        'Βουνάργου',
        'Βουναίνων',
        'Βουναρίων',
        'Βουνιατάδων',
        'Βουνιχώρας',
        'Βουνοπλαγιάς',
        'Βουνού',
        'Βουρβούλου',
        'Βουρβούρων',
        'Βουργαρελίου',
        'Βουρκωτής',
        'Βουρλιωτών',
        'Βουρνικά',
        'Βουτά',
        'Βουταίνης',
        'Βουτιάνων',
        'Βουτσίμου',
        'Βουτσαρά',
        'Βουτύρου',
        'Βουτών',
        'Βουχωρίνας',
        'Βοχαϊκού',
        'Βούλας',
        'Βούλπης',
        'Βούνων',
        'Βούρμπιανης',
        'Βούτση',
        'Βράχας',
        'Βράχου',
        'Βρίας',
        'Βρίνας',
        'Βρίσας',
        'Βραΐλας',
        'Βραγγιανών',
        'Βραγιά',
        'Βραγκιανών',
        'Βραδέτου',
        'Βρασνών',
        'Βραστάμων',
        'Βραχασίου',
        'Βραχατίου',
        'Βραχιάς',
        'Βραχναιίκων',
        'Βρεσθένων',
        'Βρεστού',
        'Βριλησσίων',
        'Βρομόβρυσης',
        'Βροντάδου',
        'Βροντής',
        'Βρονταμά',
        'Βροντερού',
        'Βροντισμένης',
        'Βροντούς',
        'Βροσίνας',
        'Βρουβιανών',
        'Βρουστίου',
        'Βρουχά',
        'Βροχίτσης',
        'Βρούτση',
        'Βρυναίνης',
        'Βρυοτόπου',
        'Βρυσέλλας',
        'Βρυσακίου',
        'Βρυσικών',
        'Βρυσιών',
        'Βρυσουλών',
        'Βρυσοχωρίου',
        'Βρυσούλας',
        'Βρυσών',
        'Βρυσών Αποκορρώνου',
        'Βρυσών Κυδωνίας',
        'Βρυτών',
        'Βρύσης',
        'Βυζίτσης',
        'Βυζικίου',
        'Βυθού',
        'Βυρωνείας',
        'Βυσσινέας',
        'Βυτίνης',
        'Βυτιναιίκων',
        'Βωλάδας',
        'Βωλεώνων',
        'Βόλβης',
        'Βόλου',
        'Βόνης',
        'Βόνιτσας',
        'Βύσσης',
        'Βώρων',
        'Γάβρου',
        'Γέρακα',
        'Γέργερης',
        'Γέρμα',
        'Γέρμας',
        'Γέροντα',
        'Γαΐου',
        'Γαβαλά',
        'Γαβαλοχωρίου',
        'Γαβαλούς',
        'Γαβρακίων',
        'Γαβριάς',
        'Γαβρισιών',
        'Γαβρολίμνης',
        'Γαζίου',
        'Γαζώρου',
        'Γαλάνης',
        'Γαλάρου',
        'Γαλήνης',
        'Γαλίφας',
        'Γαλανάδου',
        'Γαλαναίϊκα',
        'Γαλανόβρυσης',
        'Γαλαξιδίου',
        'Γαλαρινού',
        'Γαλατά',
        'Γαλατάδων',
        'Γαλατίστης',
        'Γαλατακίου',
        'Γαλατείας',
        'Γαλατινής',
        'Γαλατσάδων',
        'Γαλατσίου',
        'Γαλατσώνας',
        'Γαλησσά',
        'Γαληψού',
        'Γαλιάς',
        'Γαλλικού',
        'Γαναδιού',
        'Γανοχώρας',
        'Γαράζου',
        'Γαρέας',
        'Γαρίπας',
        'Γαργαλιάνων',
        'Γαρδελάδων',
        'Γαρδικίου',
        'Γαρδικίου Σούλι',
        'Γαρεφείου',
        'Γαρούνας',
        'Γαστουρίου',
        'Γαστούνης',
        'Γαυρίου',
        'Γαϊτανίου',
        'Γαύδου',
        'Γδοχίων',
        'Γελάνθης',
        'Γελινιατίκων',
        'Γενεσίου',
        'Γενισέας',
        'Γενναδίου',
        'Γερακίου',
        'Γερακαρίου',
        'Γερακαρούς',
        'Γερακιούς',
        'Γερακλίου',
        'Γερανίου',
        'Γερανίων',
        'Γεροπλατάνου',
        'Γεφυρίων',
        'Γεφυρουδίου',
        'Γεφύρας',
        'Γεωργάνων',
        'Γεωργανάδων',
        'Γεωργιανής',
        'Γεωργιανών',
        'Γεωργικού',
        'Γεωργιουπόλεως',
        'Γεωργιτσίου',
        'Γιάλτρων',
        'Γιάννουλης',
        'Γιαννάδων',
        'Γιανναίων',
        'Γιαννακοχωρίου',
        'Γιαννιτσίου',
        'Γιαννιτσοχωρίου',
        'Γιαννιτσούς',
        'Γιαννιτσών',
        'Γιαννοπούλων',
        'Γιαννωτών',
        'Γιμαρίου',
        'Γιουργάνιστας',
        'Γιρομερίου',
        'Γκαγκαλών',
        'Γκανέϊκα',
        'Γκοριτσάς',
        'Γκούρας',
        'Γκρίκας',
        'Γκραίκα',
        'Γκριμπόβου',
        'Γλάστρας',
        'Γλίνου',
        'Γλαφυρών',
        'Γλαύκης',
        'Γλινάδου',
        'Γλυκής',
        'Γλυκομηλέας',
        'Γλυκορριζίου',
        'Γλυκόβρυσης',
        'Γλυκών Νερών',
        'Γλυφάδα',
        'Γλυφάδας',
        'Γλύφας',
        'Γλώσσης',
        'Γολάς',
        'Γοματίου',
        'Γονίμου',
        'Γονούσσης',
        'Γοράνων',
        'Γοργοβιτών',
        'Γοργογυρίου',
        'Γοργομύλου',
        'Γοργοποτάμου',
        'Γοργόπη',
        'Γορτυνίας',
        'Γουβών',
        'Γουλεδιανών',
        'Γουλεμίου',
        'Γουλών',
        'Γουμένισσας',
        'Γουμέρου',
        'Γουριάς',
        'Γουριωτίσσης',
        'Γράμου',
        'Γρίβας',
        'Γραίκα',
        'Γραβιάς',
        'Γραβούνης',
        'Γραικικού',
        'Γραικοχωρίου',
        'Γραικού',
        'Γραμβουσής',
        'Γραμμένης',
        'Γραμμένης Οξυάς',
        'Γραμμένου',
        'Γραμματικού',
        'Γραμματικούς',
        'Γραμμενίτσης',
        'Γραμμούσης',
        'Γραμπιάς',
        'Γρανίτου',
        'Γρανίτσης',
        'Γρανιτσαιίκων',
        'Γρανιτσοπούλας',
        'Γρατίνη',
        'Γρεβενιτίου',
        'Γρεβενών',
        'Γρηγορίας',
        'Γρηγορίου',
        'Γρηγόρη',
        'Γριζάνου',
        'Γριζάτων',
        'Γριμπόβου',
        'Γρύλλου',
        'Γυθείου',
        'Γυμνοτόπου',
        'Γυμνού',
        'Γυναικοκάστρου',
        'Γυρίου',
        'Γωνιάς',
        'Γωνιών Μαλεβιζίου',
        'Γόμφων',
        'Γόννων',
        'Δάρα',
        'Δάφνης',
        'Δάφνου',
        'Δένδρου',
        'Δένδρων Τυρνάβου',
        'Δένδρων Φαρσάλων',
        'Δέσης',
        'Δήμητρας',
        'Δίβρης',
        'Δίου',
        'Δαδιάς',
        'Δαιμονίας',
        'Δαλαμανάρας',
        'Δαμάστας',
        'Δαμαβόλου',
        'Δαμακινίου',
        'Δαμανίων',
        'Δαμασίου',
        'Δαμασκηνιάς',
        'Δαματρίας',
        'Δαμουλιανάτων',
        'Δανακού',
        'Δαράτσου',
        'Δαρμένη',
        'Δασκίου',
        'Δασολόφου',
        'Δασοχωρίου',
        'Δασυλλίου',
        'Δασωτού',
        'Δαυγάτων',
        'Δαυλείας',
        'Δαφίων',
        'Δαφνέ',
        'Δαφνίου',
        'Δαφνιά',
        'Δαφνιωτίσσης',
        'Δαφνοσπηλιάς',
        'Δαφνουδίου',
        'Δαφνοφύτου',
        'Δαφνούλας',
        'Δαφνούσσης',
        'Δαφνωτής',
        'Δαφνών',
        'Δειλινά',
        'Δελβινακίου',
        'Δελβινακοπούλου',
        'Δελερίων',
        'Δελιανών',
        'Δελφίνου',
        'Δελφών',
        'Δεματίου',
        'Δεμεστίχων',
        'Δενδροχωρίου',
        'Δερβενίου',
        'Δερβιζιάνων',
        'Δερματίου',
        'Δεσινού',
        'Δεσκάτης',
        'Δεσποτικού',
        'Δεσφίνης',
        'Δεσύλλα',
        'Δημαίνης',
        'Δημαρίου',
        'Δημητρητσίου',
        'Δημητροπούλου',
        'Δημητσάνης',
        'Διάβας',
        'Διάσελλου',
        'Διαβατού',
        'Διαβατών',
        'Διαβολιτσίου',
        'Διακοπίου',
        'Διακοπτού',
        'Διαλεκτού',
        'Διασέλλου',
        'Διασέλλων',
        'Διασελλακίου',
        'Διβαράτων',
        'Διγελιωτίκων',
        'Διδυμοτείχου',
        'Διδύμας',
        'Διδύμων',
        'Διευχών',
        'Δικάστρου',
        'Δικαίων',
        'Δικορύφου',
        'Διλινάτων',
        'Διλόφου',
        'Διλόφου Λαρίσης',
        'Διλόφου Φαρσάλων',
        'Διμηνίου',
        'Διμηνιού',
        'Διμοκορίου',
        'Διμυλιάς',
        'Διοδίων',
        'Διομηδείας',
        'Διονυσίου',
        'Διονύσου',
        'Διπλατάνου',
        'Διποτάμου',
        'Διποταμιάς',
        'Δισπηλίου',
        'Διστράτου',
        'Διστόμου',
        'Διχειμάρρου',
        'Διχομοιρίου',
        'Διχωρίου',
        'Δοβλά',
        'Δοκιμίου',
        'Δοκός',
        'Δολίχης',
        'Δολιανών',
        'Δολού',
        'Δολών',
        'Δομίρου',
        'Δομβραίνης',
        'Δομενίκου',
        'Δομιανών',
        'Δομνίστης',
        'Δομοκού',
        'Δονούσης',
        'Δοξάτου',
        'Δοξαρά',
        'Δοξαρού',
        'Δορίσκου',
        'Δορβιτσιάς',
        'Δοτσικού',
        'Δουκάδων',
        'Δουκαναιίκων',
        'Δουλίου',
        'Δουμενών',
        'Δουμπιών',
        'Δουναίικων',
        'Δούκα',
        'Δράμας',
        'Δρίμιτσας',
        'Δραΐνας',
        'Δραβήσκου',
        'Δραγάνου',
        'Δραγασιάς',
        'Δραγοψάς',
        'Δραγωγίου',
        'Δρακαίων',
        'Δρακείας',
        'Δρακοβουνίου',
        'Δρακόνας',
        'Δρακότρυπας',
        'Δραμεσιών',
        'Δραπανιά',
        'Δραπετσώνας',
        'Δρεπάνου',
        'Δριμίσκου',
        'Δροσάτου',
        'Δροσίνη',
        'Δροσερού',
        'Δροσιά',
        'Δροσιάς',
        'Δροσινή',
        'Δροσοπηγής',
        'Δροσοχωρίου',
        'Δρυάλου',
        'Δρυμάδων',
        'Δρυμαίας',
        'Δρυμού',
        'Δρυοβούνου',
        'Δρυοφύτου',
        'Δρυόπης',
        'Δρύμη',
        'Δυρραχίου',
        'Δυσβάτου',
        'Δυτικής Φραγκίστας',
        'Δυτικού',
        'Δωδώνης',
        'Δωματίων',
        'Δωρίου',
        'Δωρικού',
        'Δωροθέας',
        'Δόλιανης',
        'Δόξης',
        'Δόριζα',
        'Δύο Βουνών',
        'Δύο Χωρίων',
        'Δύστου',
        'Εβροπούλων',
        'Εγγαρών',
        'Εγκλουβής',
        'Εδέσσης',
        'Εθιάς',
        'Εθνικού',
        'Ειδομένης',
        'Ειρηνικού',
        'Εκάλης',
        'Εκκάρας',
        'Εκκλησιών',
        'Εκκλησοχωρίου',
        'Εκκλησούλας',
        'Ελάτας',
        'Ελάτειας',
        'Ελάτης',
        'Ελάτου',
        'Ελάφου',
        'Ελίκας',
        'Ελίκης',
        'Ελαίας',
        'Ελαιοφύτου',
        'Ελαιοχωρίου',
        'Ελαιοχωρίων',
        'Ελαταριάς',
        'Ελατείας',
        'Ελατοχωρίου',
        'Ελατούς',
        'Ελατόβρυσης',
        'Ελαφονήσου',
        'Ελαφοχωρίου',
        'Ελαφότοπου',
        'Ελενών',
        'Ελεούσης',
        'Ελευθέρνης',
        'Ελευθέρου',
        'Ελευθερίου',
        'Ελευθερίου-Κορδελιού',
        'Ελευθεριανής',
        'Ελευθερουπόλεως',
        'Ελευθεροχωρίου',
        'Ελευθερών',
        'Ελικίστρας',
        'Ελληνίτσης',
        'Ελληνικού',
        'Ελληνικών',
        'Ελληνοεκκλησίας',
        'Ελληνοκάστρου',
        'Ελληνοπύργου',
        'Ελληνοχωρίου',
        'Ελλοπίας',
        'Ελούντας',
        'Εμμανουήλ Παππά',
        'Εμπάρου',
        'Εμπεσού',
        'Εμπορίου',
        'Εμπορείου',
        'Εμπορειού',
        'Εμπροσνέρου',
        'Ενορίας',
        'Εξάρχου',
        'Εξαλόφου',
        'Εξαμιλίων',
        'Εξανθείας',
        'Εξαπλατάνου',
        'Εξοχή',
        'Εξοχής',
        'Εξοχικού',
        'Εξωγής',
        'Εξωχωρίου',
        'Επάνω Βαθείας',
        'Επανομής',
        'Επανωχωρίου',
        'Επιβατών',
        'Επιδαύρου',
        'Επινιανών',
        'Επισκέψεως',
        'Επισκοπής',
        'Επισκοπής Γωνιάς',
        'Επισκοπής Νάουσας',
        'Επισκοπικού',
        'Επιταλίου',
        'Επταλόφου',
        'Επταμύλων',
        'Επταχωρίου',
        'Ερασμίου',
        'Ερατεινής',
        'Ερατεινού',
        'Ερατύρας',
        'Ερεικούσσης',
        'Ερεσού',
        'Ερετρίας',
        'Ερινεού',
        'Ερμακιάς',
        'Ερμητσίου',
        'Ερμιόνης',
        'Ερμουπόλεως',
        'Ερυθραίας',
        'Ερυθρών',
        'Ερυμανθείας',
        'Εσοχή',
        'Εσωβάλτων',
        'Εσωχωρίων',
        'Ευάνδρου',
        'Ευαγγελισμού',
        'Ευαγγελισμού Λαρίσης',
        'Ευαγγελιστρίας',
        'Ευγήρου',
        'Ευδήλου',
        'Ευζώνων',
        'Ευηνοχωρίου',
        'Ευκαρπίας',
        'Ευλάλου',
        'Ευμοίρου',
        'Ευξεινουπόλεως',
        'Ευπαλίου',
        'Ευρωπού',
        'Ευρωστίνης Ροζενών',
        'Ευόσμου',
        'Εφέσου',
        'Εφύρας',
        'Εχίνου',
        'Εύας',
        'Ζάκα',
        'Ζάκρου',
        'Ζάρκου',
        'Ζήριας',
        'Ζίρου',
        'Ζίτσης',
        'Ζίχνης',
        'Ζαγκλιβερίου',
        'Ζαγοράς',
        'Ζακυνθίων',
        'Ζαλόγγου',
        'Ζαππείου',
        'Ζαράκων',
        'Ζαρκαδιάς',
        'Ζαρού',
        'Ζαρούχλης',
        'Ζατούνης',
        'Ζαχάρως',
        'Ζαχλωριτίκων',
        'Ζαχλωρούς',
        'Ζαϊμίου',
        'Ζελίου',
        'Ζεμενού',
        'Ζενίων',
        'Ζερβοχωρίου',
        'Ζερμπισίων',
        'Ζευγαρακίου',
        'Ζευγολατείου',
        'Ζευγολατιού',
        'Ζεφυρίου',
        'Ζηλευτής',
        'Ζηλευτού',
        'Ζιγοβιστίου',
        'Ζουνακίου',
        'Ζουριδίου',
        'Ζούζουλης',
        'Ζυγού',
        'Ζυμπραγού',
        'Ζυφιά',
        'Ζωής',
        'Ζωγράφου',
        'Ζωνιανών',
        'Ζωοδόχου',
        'Ζωοδόχου Πηγής',
        'Ζωριάνου',
        'Ζωτικού',
        'Ζωφόρων',
        'Ζόλων',
        'Ζώνης',
        'Ηγουμενίτσης',
        'Ηλέκτρας',
        'Ηλιοκάλης',
        'Ηλιοκάστρου',
        'Ηλιοκώμης',
        'Ηλιορράχης',
        'Ηλιοχωρίου',
        'Ηλιούπολης',
        'Ηλιόλουστο',
        'Ημεροβιγλίου',
        'Ηραίου',
        'Ηρακλίτσης',
        'Ηρακλείας',
        'Ηρακλείου',
        'Θάνα',
        'Θάνους',
        'Θάσου',
        'Θέας',
        'Θέρμης',
        'Θέρμου',
        'Θήρας',
        'Θίσβης',
        'Θαλαμών',
        'Θαλερού',
        'Θαρουνίων',
        'Θαυμακού',
        'Θεισόας',
        'Θεμέλου',
        'Θεοδοσίων',
        'Θεοδωρακίου',
        'Θεοδωρακείου',
        'Θεοδωριάνων',
        'Θεοδώρας',
        'Θεοκτίστου',
        'Θεολόγου',
        'Θεοπέτρας',
        'Θερίσου',
        'Θεραπειό',
        'Θεριακησίου',
        'Θεριανού',
        'Θερινού',
        'Θερμησίας',
        'Θερμοπυλών',
        'Θερμών',
        'Θεσπιών',
        'Θεσπρωτικού',
        'Θεσσαλονίκης',
        'Θηβαίων',
        'Θηναίας',
        'Θηρασίας',
        'Θηριοπέτρας',
        'Θολαρίων',
        'Θολοποταμίου',
        'Θολού',
        'Θουρίας',
        'Θουρίου',
        'Θούριο Θουρίου',
        'Θρακομακεδόνων',
        'Θραψανού',
        'Θραψιμίου',
        'Θροφαρίου',
        'Θρυλορίου',
        'Θρόνου',
        'Θυμιανών',
        'Θυρίου',
        'Θωκνίας',
        'Ιάσιον',
        'Ιάσμου',
        'Ιαλυσού',
        'Ιβήρων',
        'Ιεραπέτρας',
        'Ιερισσού',
        'Ιερομνήμης',
        'Ιεροπηγής',
        'Ιητών',
        'Ιθάκης',
        'Ιθώμης',
        'Ικλαίνης',
        'Ιλίου',
        'Ιμέρου',
        'Ιμέρων',
        'Ινάχου',
        'Ινίου',
        'Ιππείου',
        'Ιρίων',
        'Ισαακίου',
        'Ισθμίας',
        'Ιστιαίας',
        'Ιστρίου',
        'Ισώματος Καρυών',
        'Ιτέα',
        'Ιτέας',
        'Ιωαννίνων',
        'Ιωαννιτών',
        'Ιωνίας',
        'Κάινας',
        'Κάλφα',
        'Κάμπου',
        'Κάμπων',
        'Κάπης',
        'Κάρπης',
        'Κάσου',
        'Κάσπακα',
        'Κάστρου',
        'Κάψα',
        'Κέδρου',
        'Κέδρων',
        'Κέλλης',
        'Κέντρου',
        'Κέχρου',
        'Κήπων',
        'Κίνυρα',
        'Κίου',
        'Κίρκης',
        'Κίρρας',
        'Καβάλας',
        'Καβάλου',
        'Καβάσιλα',
        'Καβαλλαρίου',
        'Καβαλλουρίου',
        'Καβασίλων',
        'Καββαδάδων',
        'Καβησού',
        'Καβουσίου',
        'Καβύλης',
        'Καγκαδίου',
        'Καδίου',
        'Καθενών',
        'Καθολικού',
        'Καινουργίου',
        'Καινούργιου Χωρίου',
        'Καισάρειας',
        'Καισαρίου',
        'Καισαριανής',
        'Κακαλετρίου',
        'Κακοβάτου',
        'Κακοδικίου',
        'Κακολάκκου',
        'Κακοπέτρου',
        'Κακοπλευρίου',
        'Κακοταρίου',
        'Κακουραίικων',
        'Καλάθου',
        'Καλάμου',
        'Καλάνδρας',
        'Καλάνου',
        'Καλής',
        'Καλής Βρύσης',
        'Καλής Κώμης',
        'Καλαβάρδα',
        'Καλαβρούζης',
        'Καλαβρύτων',
        'Καλαθενών',
        'Καλαμάτας',
        'Καλαμίου',
        'Καλαμακίου',
        'Καλαμαρά',
        'Καλαμαριάς',
        'Καλαμαύκας',
        'Καλαμιά',
        'Καλαμιάς',
        'Καλαμιτσίου',
        'Καλαμιτσίου Αλεξάνδρου',
        'Καλαμιτσίου Αμυγδαλίου',
        'Καλαμπάκας',
        'Καλαμπακίου',
        'Καλαμωτής',
        'Καλαμωτού',
        'Καλανίστρας',
        'Καλανδαρές',
        'Καλαποδίου',
        'Καλαρρυτών',
        'Καλαφατιώνων',
        'Καλεντίνης',
        'Καλεντζίου',
        'Καλεσιών',
        'Καλεσμένου',
        'Καλημεριάνων',
        'Καληράχης',
        'Καλιανών',
        'Καλιδόνης',
        'Καλιπάδου',
        'Καλιτσαίνης',
        'Καλλίου',
        'Καλλίστη',
        'Καλλίστης',
        'Καλλεργιανών',
        'Καλλιανίου',
        'Καλλιανού',
        'Καλλιδρόμου',
        'Καλλιθέας',
        'Καλλιθέας Σουλίου',
        'Καλλιθέας Φαρσάλων',
        'Καλλιθέας Φιλιατών',
        'Καλλιθήρου',
        'Καλλικράτειας',
        'Καλλικώμου',
        'Καλλιμασιάς',
        'Καλλινίκης',
        'Καλλιπεύκης',
        'Καλλιπόλεως',
        'Καλλιράχης',
        'Καλλιρρόης',
        'Καλλιφωνίου',
        'Καλλιφύτου',
        'Καλλιόπης',
        'Καλλονής',
        'Καλλυντήριον',
        'Καλοβάτου',
        'Καλογέρου',
        'Καλογήρων',
        'Καλογερεσίου',
        'Καλογερικού',
        'Καλογερόρραχης',
        'Καλογριανής',
        'Καλογριανών',
        'Καλοκάστρου',
        'Καλομοίρας',
        'Καλονερίου',
        'Καλονύκτου',
        'Καλοσκοπής',
        'Καλουδίου',
        'Καλουδιανών',
        'Καλουσίου',
        'Καλουτά',
        'Καλοχίου',
        'Καλοχωρίου',
        'Καλοχωρίου-Παντειχίου',
        'Καλού Αγρού',
        'Καλού Νερού',
        'Καλού Χωρίου',
        'Καλπακίου',
        'Καλτεζών',
        'Καλυβίων',
        'Καλυβίων Θορικού',
        'Καλυβίων Μυρτουντίων',
        'Καλυβίων Σοχάς',
        'Καλυβακίων',
        'Καλυβών',
        'Καλυδονίας',
        'Καλυθιών',
        'Καλυμνίων',
        'Καλύβου',
        'Καλών Δένδρων',
        'Καλών Νερών',
        'Καμάρας',
        'Καμάρων',
        'Καμένης',
        'Καμένων Βούρλων',
        'Καμήλας',
        'Καμαρίνας',
        'Καμαρίου',
        'Καμαρίτσης',
        'Καμαρίων',
        'Καμαριώτου',
        'Καμαρούλας',
        'Καμαρωτού',
        'Καμαρών',
        'Καματερού',
        'Καμενίτσης',
        'Καμενιάνων',
        'Καμηλαρίου',
        'Καμινίων',
        'Καμινακίου',
        'Καμιναράτων',
        'Καμισιανών',
        'Καμπάνη',
        'Καμπής',
        'Καμπανού',
        'Καμπιών',
        'Καμποχωρίου',
        'Κανακάδων',
        'Καναλίου',
        'Καναλίων',
        'Καναλλακίου',
        'Κανδάλου',
        'Κανδάνου',
        'Κανδήλας',
        'Καπανδριτίου',
        'Καπαρελλίου',
        'Καπελέτου',
        'Καπεσόβου',
        'Καπλανίου',
        'Καπνοφύτου',
        'Καπνοχωρίου',
        'Καππά',
        'Καππαδοκικού',
        'Καππαριάς',
        'Καράνου',
        'Καράτουλα',
        'Καράτουλα Κυνουρίας',
        'Καράτουλα Μεγαπόλεως',
        'Καρέας',
        'Καρές',
        'Καρίτσης',
        'Καρίτσης Δολόπων',
        'Καρίτσης Καρπενησίου',
        'Καραβά',
        'Καραβάδου',
        'Καραβομύλου',
        'Καραβοστάμου',
        'Καραιίκων',
        'Καρατζά',
        'Καραϊσκάκη',
        'Καρβάλης',
        'Καρβασαρά',
        'Καρβελά',
        'Καρβελίου',
        'Καρβουνάδων',
        'Καρβουναρίου',
        'Καρδίας',
        'Καρδίτσης',
        'Καρδαμά',
        'Καρδαμαίνης',
        'Καρδαμύλης',
        'Καρδαμύλων',
        'Καρδαρά',
        'Καρδαριτσίου',
        'Καρδιάς',
        'Καρδιακαυτίου',
        'Καρδιανής',
        'Καρδιτσομαγούλας',
        'Καριανής',
        'Καρινών',
        'Καριταίνης',
        'Καριωτίου',
        'Καριωτών',
        'Καρκιναγρίου',
        'Καρλοβασίων',
        'Καρνασίου',
        'Καρνεζαίικων',
        'Καροπλεσίου',
        'Καρουζανών',
        'Καρουσάδων',
        'Καρουτών',
        'Καρπάθου',
        'Καρπασίου',
        'Καρπενησίου',
        'Καρπερής',
        'Καρπερού',
        'Καρποφόρων',
        'Καρποχωρίου',
        'Καρτεράδου',
        'Καρτερίου',
        'Καρτερολίου',
        'Καρτερών',
        'Καρυάς',
        'Καρυδίου',
        'Καρυδίου Μιραμπέλλου',
        'Καρυδίτσας',
        'Καρυδιάς',
        'Καρυοβουνίου',
        'Καρυουπόλεως',
        'Καρυοφύτου',
        'Καρυοχωρίου',
        'Καρυωτίσσης',
        'Καρυών',
        'Καρωτής',
        'Καρύστου',
        'Καρών Αποκορρώνου',
        'Καρών Κισσάμου',
        'Κασάνου',
        'Κασσανδρείας',
        'Κασσανδρηνού',
        'Κασσιόπης',
        'Καστάνιανης',
        'Καστέλλας',
        'Καστέλλου',
        'Κασταμονίτσης',
        'Καστανέας',
        'Καστανέας Επιδαύρου Λιμηράς',
        'Καστανίτσης',
        'Καστανίων',
        'Καστανερής',
        'Καστανεών',
        'Καστανιάς',
        'Καστανιωτίσσης',
        'Καστανοφύτου',
        'Καστανοχωρίου',
        'Καστανούλας',
        'Καστανούσσης',
        'Καστανώνος Ζαγορίου',
        'Καστελλάνων Γύρου',
        'Καστελλάνων Μέσης',
        'Καστελλίου',
        'Καστελλίου Φουρνής',
        'Καστελλίων',
        'Καστελλιανών',
        'Καστορίας',
        'Καστορείου',
        'Καστού',
        'Καστρίου',
        'Καστρίτσης',
        'Καστρίων',
        'Καστρακίου',
        'Καστριτσίου',
        'Καστριωτίσσης',
        'Κατάκαλης',
        'Καταβόθρας',
        'Κατακαλίου',
        'Κατακοίλου',
        'Κατακόλου',
        'Καταλάκκου',
        'Καταλαγαρίου',
        'Καταλωνίων',
        'Καταμάχης',
        'Καταπόλων',
        'Καταρράκτου',
        'Κατασταρίου',
        'Καταφυγίου',
        'Καταφυλλίου',
        'Καταφύτου',
        'Καταχά',
        'Κατερίνης',
        'Κατοχής',
        'Κατούνας',
        'Κατούνης',
        'Κατσίμπαλη',
        'Κατσαρού',
        'Κατσαρωνίου',
        'Κατσιδωνίου',
        'Κατσικά',
        'Κατταβίας',
        'Κατωγής',
        'Κατωμερίου',
        'Κατωχωρίου',
        'Καυκάσου',
        'Καυκωνίας',
        'Καψάλων',
        'Καψοράχης',
        'Κελεφά',
        'Κεντρικής',
        'Κεντρικού',
        'Κεντροχωρίου',
        'Κεράμου',
        'Κεράς',
        'Κερίου',
        'Κεραμέ',
        'Κεραμίου',
        'Κεραμίτσης',
        'Κεραματών',
        'Κεραμείας',
        'Κεραμείων',
        'Κεραμειών',
        'Κεραμιδίου',
        'Κεραμιδιάς',
        'Κεραμουτσίου',
        'Κεραμωτής',
        'Κερασέα',
        'Κερασέας',
        'Κερασίτσης',
        'Κερασίων',
        'Κερασεών',
        'Κερασιάς',
        'Κερασοχωρίου',
        'Κεραστάρη',
        'Κερασόβου',
        'Κερατέας',
        'Κερατσινίου',
        'Κερδυλίων',
        'Κερκίνης',
        'Κερκυραίων',
        'Κερπινής',
        'Κερτέζης',
        'Κερυνείας',
        'Κεσσάνης',
        'Κεστρίνης',
        'Κεφάλου',
        'Κεφαλά',
        'Κεφαλίου',
        'Κεφαλαρίου',
        'Κεφαλινού',
        'Κεφαλοβρυσίου',
        'Κεφαλοβρύσου',
        'Κεφαλοχωρίου',
        'Κεφαλόβρυσης',
        'Κεχρινιάς',
        'Κεχριών',
        'Κεχροκάμπου',
        'Κηκίδιον',
        'Κηπίων',
        'Κηπουρείου',
        'Κηρίνθου',
        'Κηφισιάς',
        'Κιβερίου',
        'Κιβωτού',
        'Κιζάριον',
        'Κιλελέρ',
        'Κιλκίς',
        'Κιμμερίων',
        'Κιμώλου',
        'Κινιδάρου',
        'Κιονίου',
        'Κιρκιζατών',
        'Κισσάμου',
        'Κισσού',
        'Κλένιας',
        'Κλήματος Ευπαλίου',
        'Κλαδά',
        'Κλαδέου',
        'Κλαδορράχης',
        'Κλαυσίου',
        'Κλείτου',
        'Κλειδίου',
        'Κλειδωνιάς',
        'Κλεινού',
        'Κλεινών',
        'Κλειούς',
        'Κλεισορρευμάτων',
        'Κλεισούρας',
        'Κλεισωρείας',
        'Κλειτορίας',
        'Κλειτσού',
        'Κλεπάς',
        'Κληματακίου',
        'Κληματιάς',
        'Κλημεντίου',
        'Κλινδιάς',
        'Κλοκοτού',
        'Κλωνίου',
        'Κνίδης',
        'Κοίλων',
        'Κοίτας',
        'Κοζάνης',
        'Κοθρέα',
        'Κοιλαδίου',
        'Κοιλιωμένου',
        'Κοιμήσεως',
        'Κοινής',
        'Κοκκάλας',
        'Κοκκίνου',
        'Κοκκίνου Χωρίου',
        'Κοκκαρίου',
        'Κοκκινίου',
        'Κοκκινιάς',
        'Κοκκινογείου',
        'Κοκκινογείων',
        'Κοκκινολιθαρίου',
        'Κοκκινομηλέας',
        'Κοκκινοπηλού',
        'Κοκκινορράχης',
        'Κοκκινοχωρίου',
        'Κοκκινόβρυσης',
        'Κοκκορά',
        'Κοκκωνίου',
        'Κοκκωτών',
        'Κολινδρού',
        'Κολιρίου',
        'Κολλινών',
        'Κολοκυθιάς',
        'Κολυμβαρίου',
        'Κολχικής',
        'Κολχικού',
        'Κομάνου',
        'Κομάρων',
        'Κομίτου',
        'Κομηλίου',
        'Κομιτάτων',
        'Κομμένου',
        'Κομνίνης',
        'Κομνηνάδων',
        'Κομνηνών',
        'Κομοτηνής',
        'Κομπηγαδίου',
        'Κομπιτσίου',
        'Κομποτάδων',
        'Κομποτίου',
        'Κομπωτής',
        'Κονίσκης',
        'Κονίτσης',
        'Κονακίων',
        'Κονιάκου',
        'Κονιδίτσης',
        'Κονισκού',
        'Κονιστρών',
        'Κονοπίνας',
        'Κονταιίκων',
        'Κοντακαιίκων',
        'Κονταραίνης',
        'Κονταριωτίσσης',
        'Κοντιά',
        'Κοντοβαζαίνης',
        'Κοντοβουνίου',
        'Κοντογενάδας',
        'Κοντοδεσποτίου',
        'Κοντολιανίκων',
        'Κοντομαρίου',
        'Κοντοπουλίου',
        'Κοντοπούλων',
        'Κοξαρές',
        'Κοπάνης',
        'Κοπανακίου',
        'Κοπανού',
        'Κορίνθου',
        'Κορίτιανης',
        'Κορακιάνας',
        'Κορακοβουνίου',
        'Κορακοχωρίου',
        'Κορησού',
        'Κορησσίας',
        'Κορθίου',
        'Κορινού',
        'Κορμίστης',
        'Κορνοφωλεάς',
        'Κορνού',
        'Κοροίβου',
        'Κορομηλέας',
        'Κορυδαλλού',
        'Κορυσχάδων',
        'Κορυφής',
        'Κορυφασίου',
        'Κορυφούλας',
        'Κορυφών',
        'Κορφιωτίσσης',
        'Κορφοβουνίου',
        'Κορφών',
        'Κορωνείας',
        'Κορωνησίας',
        'Κορωνούδας',
        'Κορώνας',
        'Κορώνης',
        'Κορώνου',
        'Κοσκίνων',
        'Κοσκινά',
        'Κοσκινού',
        'Κοσμά',
        'Κοσμαδαίων',
        'Κοσματίου',
        'Κοσμηράς',
        'Κοτρωνίου',
        'Κοτσανοπούλου',
        'Κοτσικιάς',
        'Κοτύλης',
        'Κουβαλάτων',
        'Κουβαρά',
        'Κουβουκλίων',
        'Κουδουνίου',
        'Κουδουνίων',
        'Κουκκουλίου',
        'Κουκκουλίων',
        'Κουκκουνάρας',
        'Κουκλεσίου',
        'Κουκλιών',
        'Κουκουλιών',
        'Κουκουναράς',
        'Κουλεντίων',
        'Κουλούρας',
        'Κουμαιίκων',
        'Κουμαραδαίων',
        'Κουμαριάς',
        'Κουμαριτσίου',
        'Κουμπουριανών',
        'Κουνάβων',
        'Κουνινάς',
        'Κουνουπίτσης',
        'Κουνουπιάς',
        'Κουνουπιδιανών',
        'Κουπακίου',
        'Κουπιών',
        'Κουρέντων',
        'Κουραμάδων',
        'Κουρεμαδίου',
        'Κουρκουλών',
        'Κουρνά',
        'Κουρουκλάτων',
        'Κουρουνίου',
        'Κουρουνίων',
        'Κουρουνιού',
        'Κουρουτών',
        'Κουρτακίου',
        'Κουρτεσίου',
        'Κουσέ',
        'Κουσπάδων',
        'Κουτίφαρη',
        'Κουταλά',
        'Κουτρούφων',
        'Κουτσίου',
        'Κουτσελιού',
        'Κουτσοποδίου',
        'Κουτσοχέρας',
        'Κουτσοχέρου',
        'Κουτσού',
        'Κουφαλίων',
        'Κουφοβούνου',
        'Κουφονησίων',
        'Κουφοπούλου',
        'Κουφού',
        'Κοχύλου',
        'Κούβελα',
        'Κούκκου',
        'Κούμανη',
        'Κούμαρη',
        'Κούμων',
        'Κούνου',
        'Κούταλης',
        'Κούτελης',
        'Κούφης',
        'Κράψης',
        'Κρήμνης',
        'Κρήνης',
        'Κρήνης Αιγιαλείας',
        'Κρήνης Πατρών',
        'Κρίνου',
        'Κραθίου',
        'Κρανέας',
        'Κρανιδίου',
        'Κρανιδίων',
        'Κρανούλας',
        'Κρασίου',
        'Κρατερού',
        'Κρεμαστής',
        'Κρεμαστού',
        'Κρεμμυδίων',
        'Κρεστένων',
        'Κρηνίδων',
        'Κρηνίτσης',
        'Κρηνών',
        'Κρηστώνης',
        'Κρητηνίας',
        'Κριατσίου',
        'Κριεζών',
        'Κριθαρακίων',
        'Κριθιάς',
        'Κρικέλλου',
        'Κριμηνίου',
        'Κρινοφύτων',
        'Κριτσάς',
        'Κροκίου',
        'Κροκεών',
        'Κροκυλείου',
        'Κρούστα',
        'Κρυονέρου',
        'Κρυονερίου',
        'Κρυονερίου Ηλείας',
        'Κρυονερίου Ολυμπίας',
        'Κρυονερίτη',
        'Κρυονερίων',
        'Κρυοπηγής',
        'Κρυσταλλοπηγής',
        'Κρυσταλλόβρυσης',
        'Κρυφοβού',
        'Κρυόβρυση',
        'Κρυόβρυσης',
        'Κρυών',
        'Κρωβύλης',
        'Κρωπίας',
        'Κρόκου',
        'Κρύας',
        'Κρύας Βρύσης',
        'Κτένιον',
        'Κτικάδου',
        'Κτιμένης',
        'Κτισμάτων',
        'Κτιστάδων',
        'Κυανής',
        'Κυδωνέας',
        'Κυδωνιών',
        'Κυθήρων',
        'Κυλλήνης',
        'Κυμίνων',
        'Κυνηγού',
        'Κυνοπιαστών',
        'Κυπαρίσσου',
        'Κυπαρισσίας',
        'Κυπαρισσίου',
        'Κυπαρισσίων',
        'Κυρά Βγένας',
        'Κυρίων',
        'Κυρακαλής',
        'Κυριάννας',
        'Κυριακής',
        'Κυριακίου',
        'Κυριακοχωρίου',
        'Κυρτώνης',
        'Κυψέλης',
        'Κυψέλης Μεθάνων',
        'Κυψελοχωρίου',
        'Κω',
        'Κωνσταντίας',
        'Κωνσταντίνων',
        'Κωνσταντινάτου',
        'Κωστάνιανης',
        'Κωστακιών',
        'Κωσταλέξη',
        'Κωσταραζίου',
        'Κωτιλίου',
        'Κωφών',
        'Κόκκινων Λουριών',
        'Κόκλα',
        'Κόμπων',
        'Κόντσικας',
        'Κόξαρης',
        'Κόρφου',
        'Κόσμιον',
        'Κότρωνα',
        'Κύθνου',
        'Κύμης',
        'Κώμης',
        'Κώστου',
        'Κώτα',
        'Λάβδα',
        'Λάβδανης',
        'Λάγιου',
        'Λάγκας',
        'Λάδης',
        'Λάκκας',
        'Λάκκων',
        'Λάλα',
        'Λάλουκα',
        'Λάμπου Μύλων',
        'Λάρδου',
        'Λάστης',
        'Λάστρου',
        'Λάτα',
        'Λέκας',
        'Λέρου',
        'Λίμνης',
        'Λίνδου',
        'Λίππας',
        'Λίστας',
        'Λαΐστης',
        'Λαέρμων',
        'Λαβάρων',
        'Λαγίας',
        'Λαγανά',
        'Λαγκάδας',
        'Λαγκαδά',
        'Λαγκαδίων',
        'Λαγκαδαιίκων',
        'Λαγκαδακίων',
        'Λαγκαδικίων',
        'Λαγοβουνίου',
        'Λαγολίου',
        'Λαγορράχης',
        'Λαγού',
        'Λαγυνών',
        'Λαγωπόδου',
        'Λαδά',
        'Λαδικούς',
        'Λαδοχωρίου',
        'Λαζαράτων',
        'Λαζαρίνας',
        'Λαιίκων',
        'Λαιμού',
        'Λακήθρας',
        'Λακκοπέτρας',
        'Λακκωμάτων',
        'Λακκωνίων',
        'Λακώνων',
        'Λαλιώτου',
        'Λαμιέων',
        'Λαμπαίνης',
        'Λαμπείας',
        'Λαμπερού',
        'Λαμπινής',
        'Λαμπινούς',
        'Λαμπιρίου',
        'Λαμπιωτών',
        'Λαμποκάμπου',
        'Λαμπρόν',
        'Λαμψάκου',
        'Λαμύρων',
        'Λανθίου',
        'Λαντζουνάτου',
        'Λαπαναγών',
        'Λαρίσης',
        'Λαρανίου',
        'Λαρύμνης',
        'Λασταιίκων',
        'Λατζοΐου',
        'Λατσίδας',
        'Λαυκίου',
        'Λαυρεωτικής',
        'Λαφιώνας',
        'Λαφυστίου',
        'Λαχίου',
        'Λαχανά',
        'Λαχανάδας',
        'Λαχανιάς',
        'Λαψίστης',
        'Λαύκας',
        'Λαύκου',
        'Λεήμονα',
        'Λεβαίας',
        'Λεβαδέων',
        'Λεβεντοχωρίου',
        'Λεβιδίου',
        'Λειανοκλαδίου',
        'Λειψυδρίου',
        'Λειψών',
        'Λεκάνης',
        'Λεοντίου',
        'Λεοντίτου',
        'Λεονταρίου',
        'Λεπενούς',
        'Λεπετύμνου',
        'Λεπιανών',
        'Λεπούρων',
        'Λεπρέου',
        'Λεπτινίου',
        'Λεπτοκαρυάς',
        'Λεπτοκαρυάς Ζαγορίου',
        'Λεπτοκαρυών',
        'Λεπτοπόδων',
        'Λεσινίου',
        'Λευκάρων',
        'Λευκίμμης',
        'Λευκαδίων',
        'Λευκαδιτίου',
        'Λευκακίων',
        'Λευκασίου',
        'Λευκογείων',
        'Λευκοθέας',
        'Λευκοπηγής',
        'Λευκοτόπου',
        'Λευκοχωρίου',
        'Λευκοχώρας',
        'Λευκού',
        'Λευκόβρυσης',
        'Λευκών',
        'Λεχαίου',
        'Λεχαινών',
        'Λεχουρίου',
        'Λεχωνίων',
        'Λεχόβου',
        'Λεωνιδίου',
        'Λεύκας',
        'Λεύκης',
        'Λεύκτρων',
        'Λημερίου',
        'Ληνός',
        'Ληξουρίου',
        'Λητής',
        'Λιανοβεργίου',
        'Λιαπάδων',
        'Λιας',
        'Λιβαδίου',
        'Λιβαδίων',
        'Λιβαδακίου',
        'Λιβαδαρίου',
        'Λιβαδερού',
        'Λιβαδιάς',
        'Λιβαδοχωρίου',
        'Λιβανατών',
        'Λιβαρτζίου',
        'Λιβερών',
        'Λιγκιάδων',
        'Λιγορτύνου',
        'Λιγοψάς',
        'Λιδωρικίου',
        'Λιθίνου',
        'Λιθίου',
        'Λιθακιάς',
        'Λιθιάς',
        'Λιθινών',
        'Λιθοβουνίων',
        'Λιθοτόπου',
        'Λιθοχωρίου',
        'Λικνάδων',
        'Λιλαίας',
        'Λιλιανού',
        'Λιμένος Χερσονήσου',
        'Λιμίνης',
        'Λιμεναρίων',
        'Λιμνίτσης',
        'Λιμνιών',
        'Λιμνοτόπου',
        'Λιμνοχωρίου',
        'Λιμνών',
        'Λιναριάς',
        'Λινισταίνης',
        'Λιοδώρας',
        'Λιοπράσου',
        'Λιοσίων',
        'Λιπαρού',
        'Λιποχωρίου',
        'Λιρών',
        'Λισβορίου',
        'Λιτοσέλου',
        'Λιτοχώρου',
        'Λογγάδων',
        'Λογγάς',
        'Λογγάστρας',
        'Λογγιτσίου',
        'Λογγού',
        'Λογκανίκου',
        'Λογοθετιανίκων',
        'Λοξάδας',
        'Λουκά',
        'Λουκισίων',
        'Λουκομίου',
        'Λουρδάτων',
        'Λουρών',
        'Λουσακιών',
        'Λουσικών',
        'Λουσών',
        'Λουτουφίου',
        'Λουτρακίου',
        'Λουτρακίου Περαχώρας',
        'Λουτροπηγής',
        'Λουτροπόλεως Θερμής',
        'Λουτροπόλεως Μεθάνων',
        'Λουτροτόπου',
        'Λουτρού',
        'Λουτρού Λαρίσης',
        'Λουτρών',
        'Λουτρών Αιδηψού',
        'Λουτρών Ηραίας',
        'Λουτρών Υπάτης',
        'Λουτσίου',
        'Λουτσών',
        'Λοφίσκου',
        'Λοφαρίου',
        'Λοχριάς',
        'Λούβρης',
        'Λούβρου',
        'Λούμα',
        'Λούρου',
        'Λούτσας',
        'Λούτσης',
        'Λούχας',
        'Λυγαριάς',
        'Λυγερέα',
        'Λυγερής',
        'Λυγιά',
        'Λυγιάς',
        'Λυδίας',
        'Λυκίσσης',
        'Λυκαίου',
        'Λυκοβρύσεως',
        'Λυκοποριάς',
        'Λυκοσούρας',
        'Λυκοστόμου',
        'Λυκοτράφου',
        'Λυκουδίου',
        'Λυκουρίας',
        'Λυκοχίων',
        'Λυκούρεση',
        'Λυκόγιαννης',
        'Λυπουδεσίου',
        'Λυρκείας',
        'Λυσιμαχείας',
        'Λυσσαρέας',
        'Λυττού',
        'Λυχνού',
        'Λόγγου',
        'Λόφου',
        'Λόφων',
        'Λύγγου',
        'Λύκειον',
        'Λύρας',
        'Λύχνων',
        'Μάγειρα',
        'Μάζης',
        'Μάζιας',
        'Μάκρης',
        'Μάλεμε',
        'Μάλης',
        'Μάλθης',
        'Μάλτας',
        'Μάναρη',
        'Μάνδρας',
        'Μάνεση',
        'Μάνης',
        'Μάννα',
        'Μάννας',
        'Μάραθα',
        'Μάρθας',
        'Μάρκου',
        'Μάστρου',
        'Μάχου',
        'Μέγα Κάμπου',
        'Μέγα Πιστόν',
        'Μέρους',
        'Μέρωνα',
        'Μέσα Διδύμας',
        'Μέσα Λακκωνίων',
        'Μέσα Λασιθίου',
        'Μέσα Μουλιανών',
        'Μέση',
        'Μέσης',
        'Μέσης Συνοικίας Τρικάλων',
        'Μέσου Γερακαρίου',
        'Μήλου',
        'Μίλα',
        'Μίνας',
        'Μίνθης',
        'Μίστρου',
        'Μαγαζιών',
        'Μαγαρικαρίου',
        'Μαγγάνων',
        'Μαγγανίτου',
        'Μαγγανιακού',
        'Μαγικού',
        'Μαγνησίας',
        'Μαγουλάδων',
        'Μαγουλίτσης',
        'Μαγουλιάνων',
        'Μαγούλας',
        'Μαδένης',
        'Μαδύτου',
        'Μαζίου',
        'Μαζαράκι',
        'Μαζαρακίου',
        'Μαζαρακιάς',
        'Μαθίας',
        'Μαθιάς',
        'Μαθρακίου',
        'Μαινάλου',
        'Μακίστου',
        'Μακράδων',
        'Μακρίνου',
        'Μακρίσης',
        'Μακρακώμης',
        'Μακρινής',
        'Μακρινίτσης',
        'Μακρινούς',
        'Μακρισίων',
        'Μακρολιβάδου',
        'Μακροταντάλου',
        'Μακροχωρίου',
        'Μακρυγιάλου',
        'Μακρυκάπας',
        'Μακρυλιάς',
        'Μακρυπλαγίου',
        'Μακρυρράχης',
        'Μακρυσίου',
        'Μακρυχωρίου',
        'Μακρυωτίκων',
        'Μακυνείας',
        'Μαλάξας',
        'Μαλίων',
        'Μαλαθύρου',
        'Μαλακάσης',
        'Μαλακίων',
        'Μαλακασίου',
        'Μαλαμάτων',
        'Μαλανδρίνου',
        'Μαλαντρενίου',
        'Μαλγάρων',
        'Μαλεσίνης',
        'Μαλεσιάδας',
        'Μαλετιάνων',
        'Μαλλωτών',
        'Μαλουνίου',
        'Μαλυκρείου',
        'Μαλών',
        'Μαμουλάδας',
        'Μαμουσιάς',
        'Μαναγούλης',
        'Μανασσή',
        'Μανδάλου',
        'Μανδηλίου',
        'Μανδρακίου',
        'Μανδρινής',
        'Μανδρών',
        'Μανεσίου Καλαβρύτων',
        'Μανεσίου Πατρών',
        'Μανθυρέας',
        'Μανιάκων',
        'Μανιακίου',
        'Μανικίων',
        'Μανολατών',
        'Μανολιάσης',
        'Μανολιοπούλου',
        'Μανταμάδου',
        'Μαντασιάς',
        'Μαντείου',
        'Μαντζαρίου',
        'Μαντινείας',
        'Μαντουδίου',
        'Μαράθου',
        'Μαρίνης',
        'Μαρίου',
        'Μαραθέας',
        'Μαραθιά',
        'Μαραθιάς',
        'Μαραθοκάμπου',
        'Μαραθοπόλεως',
        'Μαραθούσσης',
        'Μαραντοχωρίου',
        'Μαρασίων',
        'Μαργαριτίου',
        'Μαργαριτών',
        'Μαργελίου',
        'Μαριολάτας',
        'Μαριού',
        'Μαριτσών',
        'Μαριών',
        'Μαρκινιάδας',
        'Μαρκοπούλου',
        'Μαρκοπούλου Μεσογαίας',
        'Μαρκοπούλου Ωρωπού',
        'Μαρμάρου',
        'Μαρμάρων',
        'Μαρμακέτου',
        'Μαρμαρά',
        'Μαρμαρίνης',
        'Μαρμαρίου',
        'Μαρουλά',
        'Μαρπήσσης',
        'Μαρτίνου',
        'Μαρωνίας',
        'Μαρωνείας',
        'Μασάρων',
        'Μασχολουρίου',
        'Ματίου',
        'Ματαράγκας',
        'Ματεσίου',
        'Ματονερίου',
        'Ματσουκίου',
        'Μαυράτων',
        'Μαυρίλου',
        'Μαυραναίων',
        'Μαυρατζαίων',
        'Μαυραχάδων',
        'Μαυρελίου',
        'Μαυρικίου',
        'Μαυριών',
        'Μαυροβάτου',
        'Μαυροβουνίου',
        'Μαυρογιάννη',
        'Μαυροδενδρίου',
        'Μαυροθαλάσσης',
        'Μαυροκάμπου',
        'Μαυροκκλησίου',
        'Μαυρολεύκης',
        'Μαυρολιθαρίου',
        'Μαυρολόφου',
        'Μαυρομμάτας',
        'Μαυρομματίου',
        'Μαυρομματίου Παμίσου',
        'Μαυρονερίου',
        'Μαυρονόρους',
        'Μαυροπηγής',
        'Μαυροπούλου',
        'Μαυρουδίου',
        'Μαυροχωρίου',
        'Μαυρούδας',
        'Μαχαιρά',
        'Μαχαιράδου',
        'Μαχαιρών',
        'Μεγάλης Βρύσης',
        'Μεγάλης Γότιστας',
        'Μεγάλης Δοξιπάρας',
        'Μεγάλης Κάψης',
        'Μεγάλης Κερασέας',
        'Μεγάλης Παναγίας',
        'Μεγάλης Στέρνας',
        'Μεγάλης Χώρας',
        'Μεγάλου Βάλτου',
        'Μεγάλου Γαρδικίου',
        'Μεγάλου Δουκάτου',
        'Μεγάλου Ελευθεροχωρίου',
        'Μεγάλου Ευυδρίου',
        'Μεγάλου Κεφαλοβρύσου',
        'Μεγάλου Μοναστηρίου',
        'Μεγάλου Περιστερίου',
        'Μεγάλου Σειρηνίου',
        'Μεγάλου Χωρίου',
        'Μεγάλων Καλυβίων',
        'Μεγάρου',
        'Μεγάρχης',
        'Μεγίστης',
        'Μεγαλοβρύσου',
        'Μεγαλοκάμπου',
        'Μεγαλοπόλεως',
        'Μεγαλοχωρίου',
        'Μεγαλόχαρης',
        'Μεγαπλατάνου',
        'Μεγαρέων',
        'Μεθώνης',
        'Μελά',
        'Μελάμπων',
        'Μελάνων',
        'Μελέτη',
        'Μελίας',
        'Μελίκης',
        'Μελίσσα',
        'Μελίσσης',
        'Μελίτης',
        'Μελανθίου',
        'Μελανιού',
        'Μελενικιτσίου',
        'Μελεσών',
        'Μελιάς',
        'Μελιανών',
        'Μελιβοίας',
        'Μελιγαλά',
        'Μελιγγών',
        'Μελιγούς',
        'Μελιδονίου',
        'Μελισσίου',
        'Μελισσίων',
        'Μελισσοκομείου',
        'Μελισσοπέτρας',
        'Μελισσοτόπου',
        'Μελισσουργακίου',
        'Μελισσουργού',
        'Μελισσουργών',
        'Μελισσοχωρίου',
        'Μελισσόπετρας',
        'Μελιτίνης',
        'Μελιταίας',
        'Μελπείας',
        'Μενδενίτσης',
        'Μενεμένης',
        'Μενετών',
        'Μενιδίου',
        'Μεξιατών',
        'Μεράς',
        'Μεριάς',
        'Μερκάδας',
        'Μερκοβουνίου',
        'Μερόπης',
        'Μεσαίας Κάψης',
        'Μεσαίου',
        'Μεσαγρού',
        'Μεσαναγρού',
        'Μεσαρίστης',
        'Μεσαριάς',
        'Μεσαριάς Άνδρου',
        'Μεσελέρων',
        'Μεσενικόλα',
        'Μεσημβρίας',
        'Μεσημερίου',
        'Μεσιάς',
        'Μεσιανής',
        'Μεσιανού',
        'Μεσινού',
        'Μεσκλών',
        'Μεσοβουνίου',
        'Μεσοβουνίων',
        'Μεσοβούνου',
        'Μεσογείου',
        'Μεσοκάμπου',
        'Μεσοκώμης',
        'Μεσολακκιάς',
        'Μεσολογγίου',
        'Μεσολουρίου',
        'Μεσολόγγου',
        'Μεσονησίου',
        'Μεσοποτάμου',
        'Μεσοποταμιάς',
        'Μεσοπύργου',
        'Μεσορράχης',
        'Μεσορρουγίου',
        'Μεσορόπης',
        'Μεσοτόπου',
        'Μεσοχωρίου',
        'Μεσοχωρίου Υπάτης',
        'Μεσοχωρίων',
        'Μεσοχώρας',
        'Μεσσήνης',
        'Μεστών',
        'Μετάλλων',
        'Μεταγκιτσίου',
        'Μεταμορφώσεως',
        'Μεταμόρφωσης',
        'Μεταξά',
        'Μεταξάδας',
        'Μεταξάδων',
        'Μεταξάτων',
        'Μεταξοχωρίου',
        'Μετοχίου',
        'Μετοχίου Διρφύων',
        'Μετοχίου Κηρέως',
        'Μετσόβου',
        'Μετόχιο Προδρόμου',
        'Μηθύμνης',
        'Μηλέα',
        'Μηλέας',
        'Μηλίνης',
        'Μηλίτσας',
        'Μηλίτσης',
        'Μηλεών',
        'Μηλιάς',
        'Μηλιανών',
        'Μηλιωτίου',
        'Μηλοχωρίου',
        'Μητάτου',
        'Μητάτων',
        'Μητροπόλεως',
        'Μητρουσίου',
        'Μηχανιώνας',
        'Μιαμούς',
        'Μιδέας',
        'Μικράς Γότιστας',
        'Μικράς Μαντινείας',
        'Μικροβάλτου',
        'Μικροθηβών',
        'Μικροκάμπου',
        'Μικροκάστρου',
        'Μικροκλεισούρας',
        'Μικρολίμνης',
        'Μικρολιβάδου',
        'Μικρομάνης',
        'Μικρομηλέας',
        'Μικροπόλεως',
        'Μικροσπηλιάς',
        'Μικροχωρίου',
        'Μικρού Βάλτου',
        'Μικρού Βουνού',
        'Μικρού Δάσους',
        'Μικρού Δερείου',
        'Μικρού Μοναστηρίου',
        'Μικρού Περιβολακίου',
        'Μικρού Περιστερίου',
        'Μικρού Ποντιά',
        'Μικρού Σουλίου',
        'Μικρού Χωρίου',
        'Μικρόν Πιστόν',
        'Μιλάτου',
        'Μιλλιαράδων',
        'Μιντιλογλίου',
        'Μιράνων',
        'Μιραλίου',
        'Μιστεγνών',
        'Μιτοπόλεως',
        'Μιχαλιτσίου',
        'Μιχοΐου',
        'Μοίρας',
        'Μοδίου',
        'Μοιρών',
        'Μολάων',
        'Μολίστης',
        'Μολυβδοσκεπάστου',
        'Μολόχας',
        'Μονής',
        'Μοναστηρίου',
        'Μοναστηρακίου',
        'Μοναχιτίου',
        'Μονεμβασίας',
        'Μονοδενδρίου',
        'Μονοδρύου',
        'Μονοκαρυάς',
        'Μονοκκλησιάς',
        'Μονολίθου',
        'Μονολιθίου',
        'Μονοπολάτων',
        'Μονοσπίτων',
        'Μονόβρυσης',
        'Μοραΐτικων',
        'Μορονίου',
        'Μορφοβουνίου',
        'Μοσιάς',
        'Μοσχάτου',
        'Μοσχοκαρυάς',
        'Μοσχοποτάμου',
        'Μοσχοφύτου',
        'Μοσχοχωρίου',
        'Μουδανιών',
        'Μουζίλου',
        'Μουζακίου',
        'Μουζακαίων',
        'Μουζακαιίκων',
        'Μουζουρά',
        'Μουλίων',
        'Μουλιανών',
        'Μουλκίου',
        'Μουρεσίου',
        'Μουριάς',
        'Μουριατάδας',
        'Μουρικίου',
        'Μουριών',
        'Μουρνές',
        'Μουρνιών',
        'Μουσάτων',
        'Μουσθένης',
        'Μουσιωτίτσης',
        'Μουσουνίτσης',
        'Μουσούρων',
        'Μοχού',
        'Μούδρου',
        'Μούντρου',
        'Μπάφρας',
        'Μπαμπίνης',
        'Μπαμπαλιού',
        'Μπαουσιών',
        'Μπατσίου',
        'Μπελοκομίτης',
        'Μπενιτσών',
        'Μπεστιάς',
        'Μπιζανίου',
        'Μποζικά',
        'Μπολατίου',
        'Μπουλαριών',
        'Μποχάλης',
        'Μπράλου',
        'Μπόρσα',
        'Μπόρσιον',
        'Μυγδαλιάς',
        'Μυκηνών',
        'Μυκονίων',
        'Μυλοποτάμου',
        'Μυλοτόπου',
        'Μυξόρρουμα',
        'Μυρίκης',
        'Μυρίνης',
        'Μυριναίων',
        'Μυριοκεφάλων',
        'Μυριοφύτου',
        'Μυρκίνου',
        'Μυρμηγκίου',
        'Μυροδάφνης',
        'Μυροφύλλου',
        'Μυρρίνης',
        'Μυρσίνης',
        'Μυρσινοχωρίου',
        'Μυρτέας',
        'Μυρτιάς',
        'Μυρτιδίων',
        'Μυρτουντίων',
        'Μυρτοφύτου',
        'Μυρωδάτου',
        'Μυρωνίων',
        'Μυρόβρυσης',
        'Μυστρά',
        'Μυτιλήνης',
        'Μυτιληνιών',
        'Μυχού',
        'Μόριας',
        'Μόρφης',
        'Μύθων',
        'Μύκης',
        'Μύλων',
        'Μύρθιου',
        'Μύρου',
        'Μύρτου',
        'Μύρων',
        'Μύστακας',
        'Μύτικα',
        'Μώλου',
        'Ν.Κερασιάς',
        'Νάξου',
        'Νάπης',
        'Νέα Σάντα',
        'Νίκης',
        'Νίπους',
        'Νίψης',
        'Ναμάτων',
        'Ναούσης',
        'Ναρθακίου',
        'Ναρκίσσου',
        'Νασίων',
        'Ναυπάκτου',
        'Ναυπακτίας',
        'Ναυπλιέων',
        'Νεάπολης',
        'Νεαπόλεως',
        'Νεγάδων',
        'Νεγράδων',
        'Νεδούσης',
        'Νεμέας',
        'Νεμούτας',
        'Νενήτων',
        'Νενητουρίων',
        'Νεοκάστρου',
        'Νεοκαισαρείας',
        'Νεοχωρίου',
        'Νεοχωρακίου',
        'Νεοχωροπούλου',
        'Νεοχωρούδας',
        'Νεράιδας',
        'Νεράντζης',
        'Νεραντζιών',
        'Νεραϊδοχωρίου',
        'Νεριανών',
        'Νεροκούρου',
        'Νερομάννας',
        'Νερομύλου',
        'Νερομύλων',
        'Νεροτριβιάς',
        'Νεροφράκτου',
        'Νεροχωρίου',
        'Νεστάνης',
        'Νεστορίου',
        'Νευροκοπίου',
        'Νεύρα',
        'Νησίου',
        'Νησακίου',
        'Νιάτων',
        'Νιγρίτης',
        'Νιθαύρεως',
        'Νικήσιανης',
        'Νικήτης',
        'Νικαίας',
        'Νικηθιανού',
        'Νικηταί',
        'Νικηφόρου',
        'Νικιών',
        'Νικοκλείας',
        'Νικολή',
        'Νικολαιίκων',
        'Νικολιτσίου',
        'Νικομηδείας',
        'Νικομηδινού',
        'Νικοπόλεως',
        'Νικοτσάρας',
        'Νικόπολης',
        'Νιπιδιτού',
        'Νιφοραιίκων',
        'Νομής',
        'Νομίων',
        'Νομιτσή',
        'Νοστίμου',
        'Νοτίας',
        'Νοχιών',
        'Ντερέ',
        'Νυβρίτου',
        'Νυδρίου',
        'Νυμφίου',
        'Νυμφαίου',
        'Νυμφασίας',
        'Νυμφοπέτρας',
        'Νυμφών',
        'Νυφίου',
        'Ξάνθης',
        'Ξαμουδοχωρίου',
        'Ξανθάτων',
        'Ξανθοχωρίου',
        'Ξενιάκου',
        'Ξενιών',
        'Ξενοπούλου',
        'Ξεριά',
        'Ξεχασμένης',
        'Ξεχώρου',
        'Ξηροκάμπου',
        'Ξηροκαμπίου',
        'Ξηροκαριταίνης',
        'Ξηρολίμνης',
        'Ξηρολόφου',
        'Ξηρονομής',
        'Ξηροπηγάδου',
        'Ξηροποτάμου',
        'Ξηροστερνίου',
        'Ξηροχωρίου',
        'Ξινονερίου',
        'Ξινού Νερού',
        'Ξινόβρυσης',
        'Ξιφιανής',
        'Ξορυχτίου',
        'Ξυλαγανής',
        'Ξυλικών',
        'Ξυλοκάστρου',
        'Ξυλοκέρας',
        'Ξυλοκερίζης',
        'Ξυλοκερατέας',
        'Ξυλοπαροίκου',
        'Ξυλοπόλεως',
        'Οάσεως',
        'Οίας',
        'Οίτης',
        'Οβριάς',
        'Οθωνών',
        'Οινουσσών',
        'Οινοφύτων',
        'Οινοχωρίου',
        'Οινούσσας',
        'Οινόης',
        'Οιτύλου',
        'Οιχαλίας',
        'Οκτωνιάς',
        'Ολβίου',
        'Ολύμπου',
        'Ολύμπων',
        'Ολύνθου',
        'Ομαλής',
        'Ομαλών',
        'Ομβριακής',
        'Ομηρικόν',
        'Ομολίου',
        'Ομορφοκκλησιάς',
        'Ομορφοχωρίου',
        'Οξυάς',
        'Οξυλίθου',
        'Οξυνείας',
        'Ορίου',
        'Οργάνης',
        'Ορεινής',
        'Ορεινού',
        'Ορεινού Ξηροβάλτου',
        'Ορθέ',
        'Ορθοβουνίου',
        'Ορθονιών',
        'Ορθουνίου',
        'Ορμενίου',
        'Ορμυλίας',
        'Ορνές',
        'Οροπεδίου',
        'Ορφανίου',
        'Ορφανών',
        'Ορχομενού',
        'Ουρανοπόλεως',
        'Οφρυνίου',
        'Οχθίων',
        'Οχυρού',
        'Πάγου',
        'Πάγων',
        'Πάδων',
        'Πάου',
        'Πάπαρη',
        'Πάργας',
        'Πάρου',
        'Πάστρας',
        'Πάτμου',
        'Πέλεκα',
        'Πέλλης',
        'Πέντε Εκκλησιών',
        'Πέπλου',
        'Πέρα Μελάνων',
        'Πέραν Τριοβασάλου',
        'Πέρδικας',
        'Πέρκου',
        'Πέρνης',
        'Πέτα',
        'Πέτρα',
        'Πέτρας',
        'Παγκαλοχωρίου',
        'Παγκρατίου',
        'Παγκρατών',
        'Παγονερίου',
        'Παγουριών',
        'Παγώνδου',
        'Παγώντα',
        'Παιανίας',
        'Πακίων',
        'Παλαίρου',
        'Παλαίστρας',
        'Παλαιάς Γιαννιτσούς',
        'Παλαιάς Καβάλας',
        'Παλαιάς Φωκαίας',
        'Παλαικάστρου',
        'Παλαιοβαρβασαίνης',
        'Παλαιοβράχας',
        'Παλαιοκάστρου',
        'Παλαιοκήπου',
        'Παλαιοκαρυάς',
        'Παλαιοκατούνας',
        'Παλαιοκατούνου',
        'Παλαιοκερασέας',
        'Παλαιοκκλησίου',
        'Παλαιοκώμης',
        'Παλαιομανίνας',
        'Παλαιομοναστήρου',
        'Παλαιοξαρίου',
        'Παλαιοπαναγίας',
        'Παλαιοπόλεως',
        'Παλαιοπύργου',
        'Παλαιοσελλίου',
        'Παλαιοχούνης',
        'Παλαιοχωρίου',
        'Παλαιοχωρίου Δωριέων',
        'Παλαιοχωρίου Μπότσαρη',
        'Παλαιοχωρίου Σιράκου',
        'Παλαιοχωρίου Τυμφρηστού',
        'Παλαιοχωρακίου',
        'Παλαιοχώρας',
        'Παλαιού Αγιονερίου',
        'Παλαιού Ελευθεροχωρίου',
        'Παλαιού Κεραμιδίου',
        'Παλαιού Λουτρού',
        'Παλαιού Μυλοτόπου',
        'Παλαιού Σκυλλιτσίου',
        'Παλαιού Φαλήρου',
        'Παλαιφύτου',
        'Παλαιόβρυσης',
        'Παλαιόστανης',
        'Παλαιών Ρουμάτων',
        'Παλαμά',
        'Παλαμαρίου',
        'Παλαμπά',
        'Παλατίων',
        'Παλατιτσίων',
        'Παλιαμπέλων',
        'Παλιουρίου',
        'Παλιουριάς',
        'Παλιούρα',
        'Παλιούρης',
        'Παλλήνης',
        'Παλλαντίου',
        'Παλούμπας',
        'Παμφίλων',
        'Παμφίου',
        'Πανάσου',
        'Παναγίας',
        'Παναγίτσας',
        'Παναγιούδας',
        'Παναγούλας',
        'Παναιτωλίου',
        'Παναρίτη',
        'Παναριτίου',
        'Πανδρόσου',
        'Πανεθήμου',
        'Πανιπερίου',
        'Πανουργιά',
        'Παντανάσσης',
        'Πανόρμου',
        'Παπάγου',
        'Παπίγκου',
        'Παπαδιανίκων',
        'Παπαφλέσσα',
        'Παππά',
        'Παππάδου',
        'Παππάδων',
        'Παππαγιάννη',
        'Παππαγιαννάδων',
        'Παππαδάτου',
        'Παππαδατών',
        'Παππαδιανών',
        'Παππαρουσίου',
        'Παππουλίων',
        'Παραβόλας',
        'Παραδείσου',
        'Παραδεισίου',
        'Παραδεισίων',
        'Παρακαλάμου',
        'Παρακοίλων',
        'Παραλία Μέσης',
        'Παραλίας',
        'Παραλίας Πλατάνου',
        'Παραλίου Άστρους',
        'Παραλιμνίου',
        'Παραλογγών',
        'Παραμέρου',
        'Παραμυθίας',
        'Παρανεστίου',
        'Παρανύμφων',
        'Παραποτάμου',
        'Παραπουγκίου',
        'Παρασκευής',
        'Παρδαλίτσης',
        'Παρθενίου',
        'Παρορίου',
        'Παρορείου',
        'Παρπαριάς',
        'Παρτίρων',
        'Πασίου',
        'Πασαλιτών',
        'Παστίδας',
        'Πασχαλίτσης',
        'Πασχαλιάς',
        'Πατερμά',
        'Πατιοπούλου',
        'Πατουλιάς',
        'Πατρέων',
        'Πατρικάτων',
        'Πατρικίου',
        'Πατρικών',
        'Πατσιανού',
        'Πατσιδερού',
        'Πατσού',
        'Παυλιάνας',
        'Παυλοπούλου',
        'Παχείας Άμμου',
        'Παχτουρίου',
        'Παχυκαλάμου',
        'Παϊδοχωρίου',
        'Παύλιανης',
        'Παύλιας',
        'Παύλου',
        'Πεδινής',
        'Πεδινού',
        'Πεδινών',
        'Πεζούλας',
        'Πεζών',
        'Πεθελινού',
        'Πειραιώς',
        'Πελάγους',
        'Πελαγίας',
        'Πελαργού',
        'Πελασγίας',
        'Πελεκάνου',
        'Πελεκανάδας',
        'Πελετών',
        'Πελλάνας',
        'Πελλήνης',
        'Πελοπίου',
        'Πελόπης',
        'Πεμονίων',
        'Πεντέλης',
        'Πενταβρύσου',
        'Πενταγιών',
        'Πεντακόρφου',
        'Πενταλόφου',
        'Πενταμοδίου',
        'Πενταπόλεως',
        'Πεντατίου',
        'Πεντεορίων',
        'Πεντολάκκου',
        'Πεπονιάς',
        'Περάμα',
        'Περάμου',
        'Περάνθης',
        'Περάτη',
        'Περίου',
        'Περίστης',
        'Περαίας',
        'Περατάτων',
        'Περατιάς',
        'Περαχωρίου',
        'Περβολακίων',
        'Περδίκκα',
        'Περδικίου',
        'Περδικακίου',
        'Περδικονερίου',
        'Περδικόβρυσης',
        'Περθωρίου',
        'Περιβλέπτου',
        'Περιβολίου',
        'Περιβολίου Δομοκού',
        'Περιβολίων',
        'Περιβολίων Κισσάμου',
        'Περιβολίων Κυδωνίας',
        'Περιβολακίου',
        'Περιβολακίων',
        'Περιγιαλίου',
        'Περιθείας',
        'Περιθιωτίσσης',
        'Περιθωρίου',
        'Περικλείας',
        'Περιστάσεως',
        'Περιστέρας',
        'Περιστεράς',
        'Περιστερίου',
        'Περιστερώνας',
        'Περιχώρας',
        'Περουλάδων',
        'Περσαίνης',
        'Περτουλίου',
        'Πεσάδας',
        'Πεστών',
        'Πεταλείας',
        'Πεταλιδίου',
        'Πετουσίου',
        'Πετράδων',
        'Πετρίλου',
        'Πετρίνας',
        'Πετρίνου',
        'Πετρίου',
        'Πετραίας',
        'Πετραλώνων',
        'Πετρανών',
        'Πετριτής',
        'Πετριτσίου',
        'Πετριών',
        'Πετροβίτσας',
        'Πετροβούνιον',
        'Πετροκεράσων',
        'Πετροκεφάλου',
        'Πετροκεφαλίου',
        'Πετροπηγής',
        'Πετροπόρου',
        'Πετροχωρίου',
        'Πετρούπολης',
        'Πετρούσσης',
        'Πετρωτού',
        'Πετρωτών',
        'Πετρών',
        'Πετρώνας',
        'Πετσάκων',
        'Πετσαλίου',
        'Πευκοδάσους',
        'Πευκοφύτου',
        'Πευκοχωρίου',
        'Πεύκης',
        'Πεύκου',
        'Πεύκων',
        'Πηγής',
        'Πηγαδίου',
        'Πηγαδίτσης',
        'Πηγαδίων',
        'Πηγαδακίων',
        'Πηγαδησάνων',
        'Πηγαδούλια',
        'Πηγαϊδακίων',
        'Πηγών',
        'Πηδάσου',
        'Πηλίου',
        'Πιάνας',
        'Πιαλείας',
        'Πικέρνη',
        'Πικερμίου',
        'Πιλαλίστρας',
        'Πινακατών',
        'Πινακοχωρίου',
        'Πιπερίτσης',
        'Πιπεριών',
        'Πιραμάς',
        'Πισίων',
        'Πισκοκεφάλου',
        'Πισοδερίου',
        'Πιστιανών',
        'Πιτίτσης',
        'Πιτροφού',
        'Πιτσίου',
        'Πιτσιδίων',
        'Πιτσιναιίκων',
        'Πιτσιωτών',
        'Πιτσών',
        'Πλάκας',
        'Πλάνου',
        'Πλάτης',
        'Πλάτσης',
        'Πλαγίων',
        'Πλαγιά',
        'Πλαγιάς',
        'Πλαγιαρίου',
        'Πλαγιών',
        'Πλαισίου',
        'Πλαισίων Μαλακασίου',
        'Πλακάδου',
        'Πλακίδας',
        'Πλακωτής',
        'Πλανητέρου',
        'Πλατάνας',
        'Πλατάνης',
        'Πλατάνου',
        'Πλαταιών',
        'Πλατανίου',
        'Πλατανίων',
        'Πλατανακίου',
        'Πλατανακίων',
        'Πλατανιά',
        'Πλατανιάς',
        'Πλατανιστού',
        'Πλατανιωτίσσης',
        'Πλατανοτόπου',
        'Πλατανούσσης',
        'Πλατανόβρυσης',
        'Πλαταριάς',
        'Πλατιάνας',
        'Πλατρειθιά',
        'Πλατυβόλας',
        'Πλατυκάμπου',
        'Πλατυστόμου',
        'Πλατυστόμων',
        'Πλεμενιανών',
        'Πληκατίου',
        'Πλουτοχωρίου',
        'Πλωμαρίου',
        'Πλώρας',
        'Πογωνίας',
        'Ποδογοράς',
        'Ποδοχωρίου',
        'Ποιμενικού',
        'Ποκίστης',
        'Πολίχνης',
        'Πολεμαρχίου',
        'Πολιανής',
        'Πολιτικών',
        'Πολιχνίτου',
        'Πολοβίτσης',
        'Πολυάνθου',
        'Πολυανέμου',
        'Πολυγύρου',
        'Πολυδένδρου',
        'Πολυδαμείου',
        'Πολυδενδρίου',
        'Πολυδρόσου',
        'Πολυδώρου',
        'Πολυθέας',
        'Πολυκάρπης',
        'Πολυκάστρου',
        'Πολυκαρπίου',
        'Πολυκαστάνου',
        'Πολυκεράσου',
        'Πολυλάκκου',
        'Πολυλόφου',
        'Πολυμύλου',
        'Πολυνέρου',
        'Πολυνερίου',
        'Πολυπέτρου',
        'Πολυπλατάνου',
        'Πολυποτάμου',
        'Πολυρράχου',
        'Πολυρρηνίας',
        'Πολυσίτου',
        'Πολυσταφύλου',
        'Πολυστύλου',
        'Πολυφύτου',
        'Πολυχρόνου',
        'Ποντικατών',
        'Ποντινής',
        'Ποντισμένου',
        'Ποντοηρακλείας',
        'Ποντοκερασέας',
        'Ποντοκώμης',
        'Ποντολιβάδου',
        'Ποροΐων',
        'Ποροβίτσης',
        'Πορτής',
        'Πορτίτσης',
        'Πορταριάς',
        'Πορτιανού',
        'Πορτοχελίου',
        'Πορτών',
        'Ποσειδωνίας',
        'Ποτάμων',
        'Ποταμίδας',
        'Ποταμιά',
        'Ποταμιάς',
        'Ποταμιών',
        'Ποταμού',
        'Ποταμούλας Μεσολογγίου',
        'Ποταμών',
        'Ποτειδαίας',
        'Ποτιδάνειας',
        'Ποτιστικών',
        'Πουγκακίων',
        'Πουλάτων',
        'Πουλίθρων',
        'Πουλιτσίου',
        'Πουλλίτσης',
        'Πουλλακίδας',
        'Πουρίου',
        'Πουρναρίου',
        'Πουρναριάς',
        'Πουρνιάς',
        'Πούρνου',
        'Πρίνας',
        'Πρίνου',
        'Πραγγίου',
        'Πραγματευτή',
        'Πραισού',
        'Πραιτωρίου',
        'Πραιτωρίων',
        'Πραμάντων',
        'Πρασέ',
        'Πρασίνου',
        'Πρασιάς',
        'Πρασιδακίου',
        'Πρασινάδας',
        'Πρασιών',
        'Πραστού',
        'Πρεβέζης',
        'Πρινέ',
        'Πρινιά',
        'Πριολίθου',
        'Προαστίου',
        'Προβατά',
        'Προδρομίου',
        'Προδρόμου',
        'Προκοπίου',
        'Προμάχων',
        'Προμυρίου',
        'Προσβόρρου',
        'Προσηλίου',
        'Προσηλίων',
        'Προσκυνά',
        'Προσκυνητών',
        'Προσοτσάνης',
        'Προσύμνης',
        'Προυσού',
        'Προφήτη Ηλία',
        'Προφήτης Ηλίας',
        'Προφήτου',
        'Προφήτου Ηλία',
        'Προφήτου Ηλιού',
        'Προφίλιας',
        'Πρωτοκκλησίου',
        'Πρωτοχωρίου',
        'Πρωτόπαππα',
        'Πρώτης',
        'Πτέρης',
        'Πτελέας',
        'Πτελέας Πλατανιάς',
        'Πτελεού',
        'Πτελοπούλας',
        'Πτεριάς',
        'Πυθίου',
        'Πυθαγορείου',
        'Πυλίου',
        'Πυλαίας',
        'Πυλωρίου',
        'Πυλωρών',
        'Πυλών',
        'Πυξαρίου',
        'Πυράς',
        'Πυργέλλας',
        'Πυργίου',
        'Πυργαδικίων',
        'Πυργακίου',
        'Πυργετού',
        'Πυργιωτίκων',
        'Πυργούς',
        'Πυρρή',
        'Πυρρίχου',
        'Πυρσόγιαννης',
        'Πωγωνιανής',
        'Πόδου',
        'Πόμπιας',
        'Πόρου',
        'Πόρπη',
        'Πόρων',
        'Πύδνας',
        'Πύλας',
        'Πύλης',
        'Πύλου',
        'Πύργου',
        'Πύργου Διρού',
        'Πύργου Ιθώμης',
        'Πύργου Καλαμών',
        'Πύργου Καλλίστης',
        'Πύργου Κιερίου',
        'Πύργου Τριφυλίας',
        'Πύργων',
        'Πύργων Θερμής',
        'Πύρρας',
        'Ράδου',
        'Ράμιας',
        'Ράξας',
        'Ράφτη',
        'Ράχη',
        'Ράχης',
        'Ρίγανης',
        'Ρίζης',
        'Ρίζου',
        'Ρίου',
        'Ραΐκου',
        'Ραβδούχας',
        'Ραβενής',
        'Ραβενίων',
        'Ραγάδα',
        'Ραγίου',
        'Ραδοβιζίου',
        'Ραιδεστού',
        'Ραμνής',
        'Ραπτοπούλου',
        'Ραφήνας',
        'Ραφταναίων',
        'Ραχούλας',
        'Ραχτάδων',
        'Ραχωνίου',
        'Ραχών',
        'Ραχώνας',
        'Ραψάνης',
        'Ραψομμάτη',
        'Ρεγκινίου',
        'Ρεθίου',
        'Ρεθύμνης',
        'Ρειχέας',
        'Ρεντίνας',
        'Ρεπανιδίου',
        'Ρεπετίστης',
        'Ρετσίνων',
        'Ρετσιανών',
        'Ρευματιάς',
        'Ρητίνης',
        'Ριαχόβου',
        'Ριγανίου',
        'Ριγκλίων',
        'Ριζίων',
        'Ριζαρίου',
        'Ριζοβουνίου',
        'Ριζομύλου',
        'Ριζοσπηλιάς',
        'Ριζού',
        'Ριζωμάτων',
        'Ριζών',
        'Ριφίου',
        'Ριόλου',
        'Ροβίων',
        'Ροβιάτας',
        'Ροβιών',
        'Ροβολιαρίου',
        'Ρογιτίκων',
        'Ρογών',
        'Ροδίτου',
        'Ροδίτσης',
        'Ροδακίνου',
        'Ροδαυγής',
        'Ροδιάς',
        'Ροδιανής',
        'Ροδινών',
        'Ροδοβανίου',
        'Ροδοδάφνης',
        'Ροδολίβους',
        'Ροδοπόλεως',
        'Ροδοτοπίου',
        'Ροδοχωρίου',
        'Ροδωνιάς',
        'Ροδωπού',
        'Ροεινού',
        'Ρομιρίου',
        'Ροποτού',
        'Ροσκάς',
        'Ρουμελής',
        'Ρουπακίου',
        'Ρουπακιάς',
        'Ρουσσοπουλίου',
        'Ρουσσοσπιτίου',
        'Ρουστίκων',
        'Ρουτσίου',
        'Ρουφά',
        'Ρουψιάς',
        'Ρούσσας Εκκλησίας',
        'Ρούσσου',
        'Ρυακίου',
        'Ρυακίων',
        'Ρυζιών',
        'Ρυμνίου',
        'Ρυσίου',
        'Ρωμαιίκου',
        'Ρωμανού',
        'Ρωμιάς',
        'Ρόδου',
        'Ρόδων',
        'Ρόκκας',
        'Σάγκα',
        'Σάλπης',
        'Σάμης',
        'Σάντας',
        'Σάρτης',
        'Σάρχου',
        'Σέκουλα',
        'Σέμπρωνα',
        'Σέρβου',
        'Σέσκλου',
        'Σέτας',
        'Σίβα',
        'Σίβας',
        'Σίδερης',
        'Σίλης',
        'Σίμου',
        'Σίνδου',
        'Σίτσαινα',
        'Σαβαλίων',
        'Σαγαιίκων',
        'Σαγιάδας',
        'Σαγκρίου',
        'Σακτουρίων',
        'Σαλάκου',
        'Σαλμενίκου',
        'Σαλμώνης',
        'Σαλονίκης',
        'Σαμίων',
        'Σαμαρίνης',
        'Σαμικού',
        'Σαμοθράκης',
        'Σαμονίδας',
        'Σαμπά',
        'Σαντομερίου',
        'Σανών',
        'Σαπουνακαίϊκων',
        'Σαπών',
        'Σαραβαλίου',
        'Σαρακήνας',
        'Σαρακηνάδου',
        'Σαρακηνών',
        'Σαρακινίου',
        'Σαρακινίου Ηραίας',
        'Σαρανταπήχου',
        'Σαρανταπόρου',
        'Σαργιάδας',
        'Σαρδινίων',
        'Σαρδών',
        'Σαρκίνης',
        'Σασάλου',
        'Σατρών',
        'Σαϊδόνας',
        'Σαϊτουρών',
        'Σβορωνάτων',
        'Σβορώνου',
        'Σγουράδων',
        'Σγουροκεφαλίου',
        'Σεβαστής',
        'Σεβαστιανών',
        'Σεβαστού',
        'Σειρών',
        'Σελέρου',
        'Σελίνου',
        'Σελεγουδίου',
        'Σελευκείας',
        'Σεληνίων',
        'Σελιάνας',
        'Σελιανιτίκων',
        'Σελλά',
        'Σελλάδων',
        'Σελλίου',
        'Σελλίων',
        'Σελλασίας',
        'Σελλών',
        'Σενίκου',
        'Σερίφου',
        'Σερβίων',
        'Σερβιανών',
        'Σερβωτών',
        'Σεργούλας',
        'Σεριζιανών',
        'Σερνικακίου',
        'Σερρών',
        'Σημάντρου',
        'Σημάντρων',
        'Σηρικαρίου',
        'Σησαμίας',
        'Σητείας',
        'Σιάμου',
        'Σιάνων',
        'Σιατίστης',
        'Σιβίστης',
        'Σιγουνίου',
        'Σιγρίου',
        'Σιδήρων',
        'Σιδαρίου',
        'Σιδερά',
        'Σιδηράδες',
        'Σιδηροκάστρου',
        'Σιδηρονέρου',
        'Σιδηροχωρίου',
        'Σικίνου',
        'Σιλάτων',
        'Σιλίμνης',
        'Σιμίζα',
        'Σιμιάδων',
        'Σιμοπούλου',
        'Σιναράδων',
        'Σινεβρού',
        'Σινιών',
        'Σινώπης',
        'Σιριλίου',
        'Σισανίου',
        'Σιστρουνίου',
        'Σισών',
        'Σιταίνης',
        'Σιταγρών',
        'Σιταρά',
        'Σιταραλώνων',
        'Σιταριάς',
        'Σιτομένων',
        'Σιτοχωρίου',
        'Σιτοχώρου',
        'Σκάλας',
        'Σκάλας Ωρωπού',
        'Σκάλωμα',
        'Σκάφης',
        'Σκήτης',
        'Σκαδού',
        'Σκαλανίου',
        'Σκαλοχωρίου',
        'Σκαλωτής',
        'Σκαμνακίου',
        'Σκαμνελλίου',
        'Σκανδάλου',
        'Σκανδαλίου',
        'Σκαρφείας',
        'Σκαφιδακίου',
        'Σκαφιδιάς',
        'Σκαφιδωτής',
        'Σκεπαρίου',
        'Σκεπαστής',
        'Σκεπαστού',
        'Σκιάδα',
        'Σκιάθου',
        'Σκιαδά',
        'Σκιλλουντίας',
        'Σκινέ',
        'Σκινέως',
        'Σκινιά',
        'Σκιώνης',
        'Σκλήθρου',
        'Σκλίβανης',
        'Σκλίβας',
        'Σκλαβοπούλας',
        'Σκληρού',
        'Σκοπέλου',
        'Σκοπής',
        'Σκοπιάς',
        'Σκοπού',
        'Σκορτσινού',
        'Σκοτάνης',
        'Σκοτίνης',
        'Σκοτεινής',
        'Σκοτούσσης',
        'Σκουληκάδου',
        'Σκουληκαριάς',
        'Σκουλουφίων',
        'Σκουραιίκων',
        'Σκουρβούλων',
        'Σκουροχωρίου',
        'Σκουρτούς',
        'Σκουτάρεως',
        'Σκουτάρου',
        'Σκουταρίου',
        'Σκουτεράς',
        'Σκουτεσιάδας',
        'Σκούπας',
        'Σκούρα',
        'Σκούρας',
        'Σκούρτων',
        'Σκρα',
        'Σκριπερού',
        'Σκύδρας',
        'Σκύρου',
        'Σμέρνας',
        'Σμέρτου',
        'Σμίλας',
        'Σμίξης',
        'Σμαρίου',
        'Σμυρτιάς',
        'Σμύρνης',
        'Σοκαρά',
        'Σολακίου',
        'Σολομού',
        'Σοπίου',
        'Σορωνής',
        'Σουδεναιίκων',
        'Σουλίου',
        'Σουλαρίου',
        'Σουληναρίου',
        'Σουλλάρων',
        'Σουλοπούλου',
        'Σουνίου',
        'Σουρωτής',
        'Σουστιάνων',
        'Σουφλίου',
        'Σοφάδων',
        'Σοφιάδας',
        'Σοφιανών',
        'Σοφικού',
        'Σοφικό',
        'Σοχού',
        'Σούγιας',
        'Σούδας',
        'Σούλου',
        'Σούρπης',
        'Σπάθαρη',
        'Σπάρτου',
        'Σπάτων-Λούτσας',
        'Σπήλιου',
        'Σπαθάδων',
        'Σπαθαρίου',
        'Σπαθαραίων',
        'Σπανοχωρίου',
        'Σπαρτιά',
        'Σπαρτιάς',
        'Σπαρτιατών',
        'Σπαρτιών',
        'Σπαρτοχωρίου',
        'Σπαρτύλα',
        'Σπερχογείας',
        'Σπετσών',
        'Σπηλίου',
        'Σπηλαίου',
        'Σπηλαίων',
        'Σπηλιάς',
        'Σπιταλίου',
        'Σπολαίτης',
        'Σπόθων',
        'Σπόων',
        'Στάβλων',
        'Στάθη',
        'Στάνου',
        'Στέρνας',
        'Στίβου',
        'Στίλιας',
        'Στίρφακας',
        'Σταβιών',
        'Σταγίρων',
        'Σταγιατών',
        'Σταδίου',
        'Σταθά',
        'Σταθμού Αγγίστης',
        'Σταθμού Μουριών',
        'Σταλού',
        'Σταμάτας',
        'Σταματινού',
        'Σταμνάς',
        'Στανού',
        'Σταροχωρίου',
        'Στασίμου',
        'Στασιού',
        'Σταυρακίου',
        'Σταυρακίων',
        'Σταυρινήδων',
        'Σταυροδρομίου',
        'Σταυροπηγίου',
        'Σταυροσκιαδίου',
        'Σταυρουπόλεως',
        'Σταυροχωρίου',
        'Σταυρού',
        'Σταυρωμένου',
        'Σταφιδοκάμπου',
        'Στειρίου',
        'Στεμνίτσης',
        'Στενής',
        'Στενημάχου',
        'Στενιών',
        'Στενού',
        'Στενυκλάρου',
        'Στερνών',
        'Στεφάνης',
        'Στεφανίου',
        'Στεφανιάς',
        'Στεφανινών',
        'Στεφανοβικείου',
        'Στεφανοβούνου',
        'Στιμάγκας',
        'Στομίου',
        'Στουππαίων',
        'Στουρναραιίκων',
        'Στράτου',
        'Στρίγκου',
        'Στρανώμης',
        'Στρατινίστης',
        'Στρατονίκης',
        'Στρατωνίου',
        'Στρεφίου',
        'Στροβλών',
        'Στρογγυλής',
        'Στρογγυλοβουνίου',
        'Στροπώνων',
        'Στρουσίου',
        'Στροφή',
        'Στροφυλιάς',
        'Στρυμονικού',
        'Στρυμονοχωρίου',
        'Στρόμης',
        'Στρύμης',
        'Στυλάριον',
        'Στυλίων',
        'Στυμφαλίας',
        'Στόλου',
        'Στόλων',
        'Στύλιας',
        'Στύλου',
        'Στύρων',
        'Στύψης',
        'Συβότων',
        'Συγκρέλλου',
        'Συκά Υπάτης',
        'Συκέας',
        'Συκής',
        'Συκαμίνου',
        'Συκαμινέας',
        'Συκεών',
        'Συκιάδας',
        'Συκολόγου',
        'Συκορράχης',
        'Συκουρίου',
        'Συλιβαινιώτικων',
        'Συμβολής',
        'Συνδένδρου',
        'Συνετίου',
        'Συνοικίας Τρικάλων',
        'Συρράκου',
        'Συρρίζου',
        'Σφάκας',
        'Σφακερών',
        'Σφακοπηγαδίου',
        'Σφελινού',
        'Σφενδαμίου',
        'Σφηκιάς',
        'Σφηνωτού',
        'Σχίνων',
        'Σχηματαρίου',
        'Σχινοκαψάλων',
        'Σχινοχωρίου',
        'Σχοινούσσης',
        'Σχολαρίου',
        'Σωκρακίου',
        'Σωληναρίου',
        'Σωσάνδρας',
        'Σωστίου',
        'Σωτήρας',
        'Σωταίνης',
        'Σωτηρίου',
        'Σωτηρίτσης',
        'Σωτηριανίκων',
        'Σύβρου',
        'Σύμης',
        'Σύρνας',
        'Σύρου',
        'Σώστης',
        'Τέμενης',
        'Τήνου',
        'Ταγαράδων',
        'Τακτικουπόλεως',
        'Ταλάντων',
        'Τανάγρας',
        'Ταξιάρχου',
        'Ταξιαρχών',
        'Ταρσινών',
        'Ταρσού',
        'Ταυρωνίτου',
        'Ταύρου',
        'Τειχίου',
        'Τεμενίων',
        'Τεμπών',
        'Τενέδου',
        'Τεριαχίου',
        'Τερπνής',
        'Τερπύλλου',
        'Τερψιθέας',
        'Τερόβου',
        'Τετρακώμου',
        'Τετραλόφου',
        'Τεφελίου',
        'Τζίβα',
        'Τζερμιάδου',
        'Τζιτζιφέ',
        'Τιθορέας',
        'Τιθρωνίου',
        'Τιτάνης',
        'Τοιχίου',
        'Τολού',
        'Τοξοτών',
        'Τοπολίων',
        'Τοπολιάνων',
        'Τουλιάτων',
        'Τουρκολέκα',
        'Τουρλάδας',
        'Τουρλωτής',
        'Τούμπας',
        'Τρίκαστρον',
        'Τρίτους',
        'Τραγάνας',
        'Τραγίλου',
        'Τραγακίου',
        'Τραγανού',
        'Τρανοβάλτου',
        'Τραπέζης',
        'Τραπεζίτσης',
        'Τραπεζαντής',
        'Τραχήλας',
        'Τραχειάς',
        'Τραχηλίου',
        'Τρεχλού',
        'Τριανδρίας',
        'Τριαντάρου',
        'Τριανταφυλλέας',
        'Τριανταφυλλιάς',
        'Τριβούνου',
        'Τριγλίας',
        'Τριγωνικού',
        'Τριδένδρου',
        'Τριζονίων',
        'Τρικάλων',
        'Τρικερίου',
        'Τρικκαίων',
        'Τρικλίνου',
        'Τρικοκκιάς',
        'Τρικορύφου',
        'Τρικόρφου',
        'Τρικώμου',
        'Τριλόφου',
        'Τριοβασάλου',
        'Τριποτάμου',
        'Τριποταμιάς',
        'Τριπόλεως',
        'Τριπύλας',
        'Τριστένου',
        'Τριταίας',
        'Τριφυλλίου',
        'Τριχωνίου',
        'Τριόδου',
        'Τροβάτου',
        'Τροπαίων',
        'Τροπαιούχου',
        'Τρυπητής',
        'Τρυπών',
        'Τρωιανάτων',
        'Τρύγονα',
        'Τρύπης',
        'Τρύφου',
        'Τσάκονης',
        'Τσάκων',
        'Τσαγγαρίου',
        'Τσαγκαράδας',
        'Τσαγκαροπούλου',
        'Τσαμαντά',
        'Τσαπουρνιάς',
        'Τσαριτσάνης',
        'Τσελεπάκου',
        'Τσεπελόβου',
        'Τσερίων',
        'Τσικαλαριών',
        'Τσικκαλιών',
        'Τσιμανδρίων',
        'Τσιπιανών',
        'Τσιταλίων',
        'Τσοτυλίου',
        'Τσουκαλάδων',
        'Τσουκαλαιίκων',
        'Τσούκκας',
        'Τυλίσου',
        'Τυμπακίου',
        'Τυμφρηστού',
        'Τυρνάβου',
        'Τυρολόης',
        'Τυρού',
        'Τυχερού',
        'Τόρνου',
        'Υαμείας',
        'Υδρούσσης',
        'Υμηττού',
        'Υπάτης',
        'Υπάτου',
        'Υπερείας',
        'Υστερνίων',
        'Υψηλάντου',
        'Υψηλής Ράχης',
        'Υψηλομετώπου',
        'Υψηλού Χωρίου',
        'Φάρου',
        'Φάρσων',
        'Φήκης',
        'Φίλια',
        'Φίλιας',
        'Φαβατάτων',
        'Φαλάνθης',
        'Φαλάννης',
        'Φαλαισίας',
        'Φαλατάδου',
        'Φαλελιανών',
        'Φαμίλας',
        'Φαναρίου',
        'Φανερωμένης',
        'Φανού',
        'Φανών',
        'Φαράκλας',
        'Φαραγγίου',
        'Φαρακλάδας',
        'Φαρακλάτων',
        'Φαρακλού',
        'Φαρσάλων',
        'Φαρών',
        'Φασκομηλιάς',
        'Φελλίου',
        'Φελλού',
        'Φενεού',
        'Φερών',
        'Φιγαλείας',
        'Φιδακίων',
        'Φιλίας',
        'Φιλίππων',
        'Φιλίων',
        'Φιλαδελφίου',
        'Φιλαδελφείας',
        'Φιλιατρών',
        'Φιλιατών',
        'Φιλιππαίων',
        'Φιλλύρα',
        'Φιλοθέης',
        'Φιλοτίου',
        'Φιλυρίας',
        'Φιλωτείας',
        'Φιλύρας',
        'Φιλύρου',
        'Φιλώτα',
        'Φιολίτη',
        'Φισίνης',
        'Φισκάρδου',
        'Φιχτίου',
        'Φλαμουριάς',
        'Φλαμπουραρίου',
        'Φλαμπουρεσίου',
        'Φλαμπούρου',
        'Φλαμπούρων',
        'Φλατσίων',
        'Φλογητών',
        'Φλωρίνης',
        'Φλόκα',
        'Φλόκας',
        'Φοινίκης',
        'Φοινικίου',
        'Φολεγάνδρου',
        'Φολόης',
        'Φοναϊτίκων',
        'Φορτοσίου',
        'Φουντωτού',
        'Φουρνάς',
        'Φουρνέ',
        'Φουρνής',
        'Φουρφουρά',
        'Φούρκας',
        'Φούρνων',
        'Φούστανης',
        'Φούφα',
        'Φράγκας',
        'Φράγκου',
        'Φρίξης',
        'Φραγκάδων',
        'Φραγκουλαιίκων',
        'Φραντάτου',
        'Φραντζή',
        'Φραντζεσκιανών Μετοχίων',
        'Φρατσίων',
        'Φρε',
        'Φρεγκαίνης',
        'Φριλιγκιανίκων',
        'Φροσύνης',
        'Φρουσιούνας',
        'Φτέρης',
        'Φτελιάς',
        'Φτερνού',
        'Φυλάκης',
        'Φυλής',
        'Φυλακής',
        'Φυλακίου',
        'Φυλακτής',
        'Φυλακτού',
        'Φυτείας',
        'Φυτειών',
        'Φυτών',
        'Φωκαίας',
        'Φωλεάς',
        'Φωσταίνης',
        'Φωτάδας',
        'Φωτεινού',
        'Φωτεινών',
        'Φωτολίβους',
        'Φόδελε',
        'Φύλλου',
        'Φύλλων',
        'Φύσκας',
        'Χάλκης',
        'Χέρσου',
        'Χίνκας',
        'Χίου',
        'Χαβαρίου',
        'Χαβδάτων',
        'Χαβριάτων',
        'Χαιρεθιανών',
        'Χαιρωνείας',
        'Χαλάνδρων',
        'Χαλάρων',
        'Χαλάστρας',
        'Χαλαζονίου',
        'Χαλανδρίου',
        'Χαλανδρίτσης',
        'Χαλικίου',
        'Χαλικίου Αμβρακίας',
        'Χαλιωτάτων',
        'Χαλκείου',
        'Χαλκερού',
        'Χαλκιά',
        'Χαλκιάδων',
        'Χαλκιδέων',
        'Χαλκιοπούλων',
        'Χαμαλευρίου',
        'Χαμεζίου',
        'Χανίων',
        'Χανδρά',
        'Χανδρινού',
        'Χανιώτη',
        'Χαράδρου',
        'Χαράς',
        'Χαράσου',
        'Χαραδιατίκων',
        'Χαρακίου',
        'Χαρακοπίου',
        'Χαραυγής',
        'Χαριάς',
        'Χαριέσσης',
        'Χαριτωμένης',
        'Χαρκίων',
        'Χαροκόπιον',
        'Χαροπού',
        'Χατζή',
        'Χαϊδαρίου',
        'Χαϊκαλίου',
        'Χειμάρρου',
        'Χειμαδιού',
        'Χειμερινού',
        'Χειμωνίου',
        'Χελιδονίου',
        'Χελυδορέου',
        'Χερσονήσου',
        'Χιδήρων',
        'Χιλιοδένδρου',
        'Χιλιομοδίου',
        'Χιονάδου',
        'Χιονάδων',
        'Χιονάτων',
        'Χιράδων',
        'Χιόνας',
        'Χλοματιανών',
        'Χλομού',
        'Χολαργού',
        'Χορηγού',
        'Χορτάτων',
        'Χορτερού',
        'Χορτιάτη',
        'Χουδετσίου',
        'Χουλιαράδων',
        'Χουμερίου',
        'Χουμεριάκου',
        'Χουμνικού',
        'Χουστουλιανών',
        'Χούνης',
        'Χράνων',
        'Χρισσού',
        'Χριστιανουπόλεως',
        'Χριστού',
        'Χρομοναστηρίου',
        'Χρούσων',
        'Χρυσάφων',
        'Χρυσής',
        'Χρυσανθίου',
        'Χρυσαυγής',
        'Χρυσοβίτσας',
        'Χρυσοβίτσης',
        'Χρυσοβεργίου',
        'Χρυσοβιτσίου',
        'Χρυσοκάστρου',
        'Χρυσοκελλαριάς',
        'Χρυσοκεφάλου',
        'Χρυσομηλέας',
        'Χρυσοπέτρας',
        'Χρυσοπηγής',
        'Χρυσορράχης',
        'Χρυσοστόμου',
        'Χρυσουπόλεως',
        'Χρυσοχωράφων',
        'Χρυσοχωρίου',
        'Χρυσού',
        'Χρωμίου',
        'Χρύσως',
        'Χωματάδας',
        'Χωρέμη',
        'Χωρίου',
        'Χωρίου Αποκορρώνου',
        'Χωρίου Κυδωνίας',
        'Χωρδακίου',
        'Χωρεπισκόπων',
        'Χωριστής',
        'Χωρυγίου',
        'Χωσιαρίου',
        'Χωστιά',
        'Χωτούσσης',
        'Χόβολης',
        'Χόικας',
        'Χόμορης',
        'Χόνδρου',
        'Χόχλιας',
        'Χώνου',
        'Χώρας',
        'Χώρας Σφακίων',
        'Ψάκας',
        'Ψήνας',
        'Ψίνθου',
        'Ψαθογιάννου',
        'Ψαθοπύργου',
        'Ψαθοτοπίου',
        'Ψαράδων',
        'Ψαρίου',
        'Ψαρών',
        'Ψαχνών',
        'Ψηλής Βρύσης',
        'Ψηλοβράχου',
        'Ψιανών',
        'Ψυχικού',
        'Ψυχρού',
        'Ωλένης',
        'Ωραίου',
        'Ωραιοκάστρου',
        'Ωρεών',
        'Ωριάς',
        'Ωρολογίου',
        'Ωρωπού',
        'Όθους',
        'Όρμης',
        'Όρμου Κορθίου',
        'Όρους',
        'Όσσης',
        'Όχθιας',
        'Ύδρας',
    )
